/*********************************************************
* function.c - functions for meansuring
*
* v_0.1
*
* Copyright (c)2014 Matej Z. All rights reserved.
* matej.zdenek@gmail.com
*********************************************************/

#include "branchFusing.h"
#include "constants.h"
#include <stdio.h>
#include <math.h>



int SlouceniVetviPredzesilovace(float* impuls1, int delka1, float* impuls2, int delka2, float* impulsSlouceny, char ZPRACOVAVANE_SOUBORY, float pomerZesileni)
{

#define KANAL_SLUCOVANI 3800

    if (delka1 != delka2)
    {
        fprintf(stderr, "Slucovani pulzu - neshoduji se delky impulzu.\n");
    }

	for (int i = 0; i < delka1-1; i++)
	{
		//zesílená vìtev je o 1 vzorek zpoždìná
		int indexZesil = i+1;
		int indexNezes = i;

		if (ZPRACOVAVANE_SOUBORY == 'L') impulsSlouceny[i] = impuls2[indexZesil];	//bere jen zesílenou vìtev
		else if (ZPRACOVAVANE_SOUBORY == 'H') impulsSlouceny[i] = impuls1[indexNezes];	//bere jen nezesílenou vìtev
		else if (ZPRACOVAVANE_SOUBORY == 'B') impulsSlouceny[i] = (impuls2[indexZesil] > KANAL_SLUCOVANI) ? impuls1[indexNezes] : impuls2[indexZesil] / pomerZesileni;
		else
		{
			fprintf(stderr, "Chybny zpusob slucovani souboru.\r\n");
			return(1);
		}
	}

	//délka slouèeného pulzu
	return delka1 - 1;
}




#define DELKA_FILTRU_POMER_ZESILENI 1024
int zpracovanoVzorkuPomerZesileni = 0;
double sumaPomeruZesileni = 0;
int beziIIR = 0;
float pomerZesileniPredzesilovace = 0;

void ClearStats(tStatItem *item)
{
    item->count = 0;
    item->sum = 0;
    item->sumPow2 = 0;
    item->minimum = INFINITY;
    item->maximum = -INFINITY;
}

///@paramKonstantaNasobeni - uzivatelem zadany poměr zesileni
void BranchFusingClearStatistics(tBranchFusingStat *stats, int onlyActual, float paramKonstantaNasobeni)
{
    ClearStats(&stats->actualIIR);
    ClearStats(&stats->actualRAW);

    if (!onlyActual)
    {
        ClearStats(&stats->totalIIR);
        ClearStats(&stats->totalRAW);

		stats->computingInitMultConst = 1;
		stats->processedIntSamples = 0;
		stats->totalInitSampesToCompute = 0;
		stats->initMultConst = 0;
		stats->discardPulses = 0;
		stats->paramKonstantaNasobeni = paramKonstantaNasobeni;
    }
}

void StoreStatistics(tStatItem *item, double value)
{
    item->count++;
    item->sum += value;
    item->sumPow2 += value*value;
    item->minimum = (value < item->minimum) ? value : item->minimum;
    item->maximum = (value > item->maximum) ? value : item->maximum;
}

//vrátí 1 když je pomer zesileni vypocitany, jinak vrati 0
int VypoctiPomerZesileniPredzesilovace(float* impuls1, int delka1, float* impuls2, int delka2, float* pomerZesileni, tBranchFusingStat *stats)
{
	if (delka1 != delka2)
    {
        fprintf(stderr, "Pomer zesileni - neshoduji se delky impulzu.\n");
    }

	for (int i = 0; i < delka1-1; i++)
	{
		int indexZesil = i+1;
		int indexNezes = i;

		if (impuls2[indexZesil] > 3400 && impuls2[indexZesil] < 3800)
		{
			//pomer zesileni z aktualnich 2 vzorku
			float aktualPomer = impuls2[indexZesil] / impuls1[indexNezes];
            StoreStatistics(&stats->actualRAW, aktualPomer);
            StoreStatistics(&stats->totalRAW, aktualPomer);


			if (zpracovanoVzorkuPomerZesileni > DELKA_FILTRU_POMER_ZESILENI)
			{
				//vypocet pomeru zesileni pomoci prumerovaciho IIR filtru
				pomerZesileniPredzesilovace = (pomerZesileniPredzesilovace * (DELKA_FILTRU_POMER_ZESILENI - 1) + aktualPomer) / DELKA_FILTRU_POMER_ZESILENI;
                StoreStatistics(&stats->actualIIR, pomerZesileniPredzesilovace);
                StoreStatistics(&stats->totalIIR, pomerZesileniPredzesilovace);
			}
			else if (zpracovanoVzorkuPomerZesileni == DELKA_FILTRU_POMER_ZESILENI)
			{
				//vziti prumeru z nekolika vzorku jako prvotni hodnota
				pomerZesileniPredzesilovace = sumaPomeruZesileni / DELKA_FILTRU_POMER_ZESILENI;
				zpracovanoVzorkuPomerZesileni++;
				beziIIR = 1;

				//statistika výpoètu prvotního zesílení
				stats->computingInitMultConst = 0;
				stats->initMultConst = pomerZesileniPredzesilovace;
			}
			else
			{
				//z prvnich nekolika vzorku se pocita prumer - dokud neznam pomer zesileni, musim pulzy zahazovat
				zpracovanoVzorkuPomerZesileni++;
				sumaPomeruZesileni += aktualPomer;

				//statistika výpoètu prvotního zesílení
				stats->computingInitMultConst = 1;
				stats->processedIntSamples = zpracovanoVzorkuPomerZesileni;
				stats->totalInitSampesToCompute = DELKA_FILTRU_POMER_ZESILENI;
			}
		}
	}

	//statistika zahozených pulzù
	if (zpracovanoVzorkuPomerZesileni < DELKA_FILTRU_POMER_ZESILENI)
	{
		stats->discardPulses++;
	}

	*pomerZesileni = pomerZesileniPredzesilovace;
	return beziIIR;
}


int BranchFusingPrintStatistics(char* s, int printHeader, tStatItem *statItem, char* text)
{
	int charNum = 0;

	//header
	if (printHeader)
	{
		charNum += sprintf(s + charNum, "branch fusing  |   minimum        mean         std       maximum |  count\n");
		charNum += sprintf(s + charNum, "-------------------------------------------------------------------------\n");
	}

	if (statItem->sum == 0 || statItem->count == 0)
	{
		charNum += sprintf(s + charNum, "no data to print statistics\n");
		return charNum;
	}

	double mean = statItem->sum / (double)statItem->count;
	double std = sqrt( (statItem->sumPow2/(double)statItem->count) - mean*mean );

	//print results
	charNum += sprintf(s + charNum,     "%10s     | %9.4f %11.4f %11.4f %13.4f |  %1.0e\n", text, statItem->minimum, mean, std, statItem->maximum, (float)statItem->count);

	return charNum;
}



int BranchFusingPrintStatisticsMultConst(char* s, tBranchFusingStat *stats)
{
	int charNum = 0;

	if (stats->paramKonstantaNasobeni == 0)
    {
        //dynamicky vypocet pomeru zesileni predzesilovace

        if (stats->computingInitMultConst)
        {
            charNum += sprintf(s + charNum, "ZAHAZUJI PULZY (vypocet pomeru zesileni predzesilovace)...  %d / %d\n", stats->processedIntSamples, stats->totalInitSampesToCompute);
        }
        else
        {
            charNum += sprintf(s + charNum, "Prvni pomer zesileni zesilovace:  %7.4f     Zahozeno pulzu: %6d\n", stats->initMultConst, stats->discardPulses);
        }
    }
    else
    {
        //pevne zadany pomer zesileni predzesilovace
        charNum += sprintf(s + charNum, "Pevne zadany pomer zesileni predzesilovace: %7.4f\n", stats->paramKonstantaNasobeni);
    }
	return charNum;
}
