/*********************************************************
* class.c - CLASIFICATOR - SCRIPT
*
* v_0.1
*
* Copyright (c)2014 Matej Z. All rights reserved.
* matej.zdenek@gmail.com
*********************************************************/

#include "class.h"
#include "loadSohaj.h"
#include "function.h"
#include "dynamZero.h"
#include "superpositions.h"
#include "params.h"
#include "constants.h"
#include "stats.h"
#include "branchFusing.h"
#include "energy.h"

#ifdef TURN_ON_UDP_ON_LINUX
#include "udp.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <signal.h>

//catch ctrl+C
int runProgram = 1;
void signal_handler(int signum)
{
	runProgram = 0;
}

//matice
int matrixEnergyAmplitude[MATRIX_SIZE * MATRIX_SIZE];    	 //vystupni matice - enerie castice je pocitana z amplitudy pulzu
int matrixEnergyIntegral[MATRIX_SIZE * MATRIX_SIZE];    	 //vystupni matice - enerie castice je pocitana z integralu celeho pulzu
int matrixSuperponovanePulzy[MATRIX_SIZE * MATRIX_SIZE];
int matrixParametrSuperpozice[MATRIX_SIZE * MATRIX_SIZE];

//impulzy
float CH1[MAX_IMPULSE_SIZE];             //impuls ke zpracovani1
float CH2[MAX_IMPULSE_SIZE];             //impuls ke zpracovani2
int delka = 0;
unsigned long long casImpulzu_ns = 0;
int pulzKompletni = 0;
unsigned long long vypadek_ns = 0;
int vypadek_pulzy = 0;

//statistiky
tStatDynamZero DynamZeroStatCH1;
tStatDynamZero DynamZeroStatCH2;
tBranchFusingStat BranchFusingStats;
tStatEnergy EnergyStats;
tStatTime TimeStats;

int main(int argc, char **argv)
{
	//parse command line params
	ParamsStruct params;
	if (!ParseCommandLineParams(argc, argv, &params)) return 1;

	//soubor se statistikami
	if (!OpenStatisticFile(params.SOUBOR_OUT)) return 1;
    PrintValues(&params, 0, GetStatisticFile());     //print command line parameters

	//otevreni vstupnich souboru
	if (params.ZPUSOB_NACITANI_DAT_VSTUPNI_UDP_PORT == 0)
	{
		if (!OpenSohajDatFile(params.SOUBOR1, params.SOUBOR2)) return 1;
	}
	//otevreni vstupniho UDP portu
	else
	{
		#ifdef TURN_ON_UDP_ON_LINUX
		if (!PrepareInputUDP(params.ZPUSOB_NACITANI_DAT_VSTUPNI_UDP_PORT)) return 1;
		#endif
	}

	//otevreni vystupniho portu
	if (params.ODESILAT_DATA_VYSTUPNI_UDP_PORT != 0)
	{
		#ifdef TURN_ON_UDP_ON_LINUX
		if (!PrepareOutputUDP(params.OUTPUT_IP, params.ODESILAT_DATA_VYSTUPNI_UDP_PORT)) return 1;
		#endif
	}

	//prepare file for storing selected impulses
	if (params.HRANICE_UKLADANI_PULZU != 0)
    {
        if (!PrepareStoringSelectedImpulses(params.SOUBOR_OUT, params.HRANICE_UKLADANI_PULZU)) return 1;
    }

	//correction table for nonlinearity of preamplifier
	InitCorrectionTable();

	//priprava matice
    VymazMatice(matrixEnergyAmplitude);
	VymazMatice(matrixEnergyIntegral);
	VymazMatice(matrixSuperponovanePulzy);
	VymazMatice(matrixParametrSuperpozice);

	//priprava detekce superpozic
	if (!tom_superposition_init()) return 1;

	//priprava statistik
	DynamZeroClearStatistics(&DynamZeroStatCH1, 0);
	DynamZeroClearStatistics(&DynamZeroStatCH2, 0);
	BranchFusingClearStatistics(&BranchFusingStats, 0, params.KONSTANTA_NASOBENI);
	EnergyClearStatistics(&EnergyStats, 0);
	TimeClearStatistics(&TimeStats, 0);

	printf("\r\n\r\n");

	//Ctrl+C is cached by my function
	signal(SIGINT, signal_handler);

	while (runProgram)
	{
		//tisk statistik - musi byt na zacatku diky "continue" pri UDP prijmu (kdyz neprijde zadny paket)
		PrintStatistics(&params);

		//nacteni dat
		if (params.ZPUSOB_NACITANI_DAT_VSTUPNI_UDP_PORT == 0)
		{
			if (!NactiPulzSohaj(CH1, CH2, &delka, &casImpulzu_ns, &pulzKompletni, &vypadek_ns, &vypadek_pulzy)) break;
		}
		else
		{
			#ifdef TURN_ON_UDP_ON_LINUX
			if (!ReceiveRAWdataPacket(CH1, CH2, &delka, &casImpulzu_ns, &pulzKompletni, &vypadek_ns, &vypadek_pulzy)) continue;
			#endif
		}
		SetTimeOfFirstReceivedPulse(casImpulzu_ns);

		//zpracovani statistik
		WriteAllStatsToString(casImpulzu_ns, &params, &DynamZeroStatCH1, &DynamZeroStatCH2, &BranchFusingStats, &EnergyStats, &TimeStats);

		//predzpracovani - nezesilena vetev
		DynamZero(CH1, delka, &DynamZeroStatCH1);
		if (params.PARAM_X == 1) CorrectNonlinearity(CH1, delka);	//correction is only for nonaplified branch of preamplifier

		//predzpracovani - zesilena vetev
		DynamZero(CH2, delka, &DynamZeroStatCH2);

		//pomer zesileni vetvi predzesilovace
		float pomerZesileni = params.KONSTANTA_NASOBENI;
		if (params.KONSTANTA_NASOBENI == 0)
		{
			if (!VypoctiPomerZesileniPredzesilovace(CH1, delka, CH2, delka, &pomerZesileni, &BranchFusingStats)) continue;
		}

		//slouceni vetvi predzesilovace
		float CHslouceny[MAX_IMPULSE_SIZE];      //impuls ke zpracovani slouceny
		int delkaSlouceny = SlouceniVetviPredzesilovace(CH1, delka, CH2, delka, CHslouceny, params.ZPRACOVAVANE_SOUBORY, pomerZesileni);

		//predzpracovani pulzu po slouceni
		Filtr_prumer3(CHslouceny, delkaSlouceny);

		//energie pulzu (amplituda a integral)
		int poziceMaxima;
		float energyAmplitude = MaximumImpulsu(CHslouceny, &poziceMaxima, delkaSlouceny);
		int prilisKratkyPulzProIntegraci;
		float energyIntegral = EnergyFromIntegral2(CHslouceny, delkaSlouceny, poziceMaxima, &EnergyStats, &prilisKratkyPulzProIntegraci);
		SaturateEnergy(&energyAmplitude, &energyIntegral, &EnergyStats);

		//diskriminacni parametr
		float parametr = 0;
		if (params.METODA == 1) parametr = Metoda_integraceDyn(CHslouceny, poziceMaxima, delkaSlouceny);
		else if (params.METODA == 2) parametr = Metoda_WBO(CHslouceny, poziceMaxima, delkaSlouceny, params.PARAM_Z);
		else fprintf(stderr, "Neznama diskriminacni metoda!\n");

		//detekce superpozic
		int superponovanyPulz = 0;
		if (params.SUPERPOSITION_THRESHOLD_BOD_ENERGIE_0 != 0)	//detekci superpozic je mozne vypnout
		{
			int parametrSuperpozice;
			superponovanyPulz = DetekujSuperpozice(CHslouceny, delkaSlouceny, params.SUPERPOSITION_THRESHOLD_BOD_ENERGIE_0, params.SUPERPOSITION_THRESHOLD_BOD_ENERGIE_MAX, energyAmplitude, parametr, &parametrSuperpozice);
			UlozObycejneDoMatice((int)energyAmplitude, parametrSuperpozice, matrixParametrSuperpozice);	//ulozi parametry superpozice
			if (superponovanyPulz == 1) UlozPulzDoMatice(energyAmplitude, parametr, 0, matrixSuperponovanePulzy, NULL, NULL);		//pulzy oznacene jako superponovane jsou ulozeny do samostane matice
		}

		//uloen pulzu do matice
		if (pulzKompletni)
        {
            int x, y;
            if (!prilisKratkyPulzProIntegraci) UlozPulzDoMatice(energyIntegral, parametr, superponovanyPulz, matrixEnergyIntegral, NULL, NULL);
            UlozPulzDoMatice(energyAmplitude, parametr, superponovanyPulz, matrixEnergyAmplitude, &x, &y);

            //odeslani vysledku pomoci UDP paketu
            if (params.ODESILAT_DATA_VYSTUPNI_UDP_PORT != 0 && superponovanyPulz == 0)
            {
                #ifdef TURN_ON_UDP_ON_LINUX
                if (!SendUDPmethodPacket(0, 0, (unsigned short)x, (unsigned short)y)) fprintf(stderr, "Nemohu odeslat UDP paket\n");
                #endif
            }
        }

		//ulozeni vybranych pulzu na disk
		if (params.HRANICE_UKLADANI_PULZU != 0) StoreSelectedImpulse(params.HRANICE_UKLADANI_PULZU, CHslouceny, delkaSlouceny, energyAmplitude, parametr);

		TimeStatsOfSavedImpulses(&TimeStats, casImpulzu_ns, pulzKompletni, vypadek_ns, vypadek_pulzy, superponovanyPulz);

		//zastaveni zpracovani
		if (ZastavZpracovani(&params)) break;
	}

	//Ctrl+C je odchytvno standardn
	signal(SIGINT, SIG_DFL);

	//statistika vech zpracovvanch impulz
	PrintTotalStats(&params, &DynamZeroStatCH1, &DynamZeroStatCH2, &BranchFusingStats, &EnergyStats, &TimeStats);

	printf("--------------------------------------------------------------------------------\n\n");

	//ulozeni matic do souboru
	if (strcmp(params.SOUBOR_OUT, "0") != 0)
	{
		UlozMatici(matrixEnergyAmplitude, params.SOUBOR_OUT, "_Eamp.csv", "Nepodarilo se ulozit hlavni matici (energie amplituda).\r\n");	//energie z amplitudy
		UlozMatici(matrixEnergyIntegral, params.SOUBOR_OUT, "_Eint.csv", "Nepodarilo se ulozit hlavni matici (energie integral).\r\n");		//energie z integralu

		if (params.SUPERPOSITION_THRESHOLD_BOD_ENERGIE_0 != 0)	//detekci superpozic je mozne vypnout
		{
			UlozMatici(matrixSuperponovanePulzy, params.SOUBOR_OUT, "_superponovanePulzy.csv", "Nepodarilo se ulozit matici se superponovanymi pulzy.\r\n");	//superponovane pulzy
			UlozMatici(matrixParametrSuperpozice, params.SOUBOR_OUT, "_parametrySuperpozic.csv", "Nepodarilo se ulozit matici s parametry superpozic.\r\n");	//parametrySuperpozic
		}
	}
	else
	{
		printf("CSV matice nebyly ulozeny\r\n");
	}

	//zavreni vstupnich souboru a UDP portu
	if (params.ZPUSOB_NACITANI_DAT_VSTUPNI_UDP_PORT == 0)
		CloseSohajFile();
	else
		#ifdef TURN_ON_UDP_ON_LINUX
		CloseInputUDP();
		#endif

	//zavreni vystupniho UDP portu
	#ifdef TURN_ON_UDP_ON_LINUX
	if (params.ODESILAT_DATA_VYSTUPNI_UDP_PORT != 0) CloseOutputUDP();
	#endif

	CloseStatisticFile();

	printf("\r\n");
    return(0);
}
