/*********************************************************
* function.c - functions for meansuring
*
* v_0.1
*
* Copyright (c)2014 Matej Z. All rights reserved.
* matej.zdenek@gmail.com
*********************************************************/

#include "function.h"
#include "stats.h"
#include "constants.h"
#include <stdio.h>

void VymazMatice(int *data){
 int a,b;

 for (a=0;a<MATRIX_SIZE;a++)
    for(b=0;b<MATRIX_SIZE;b++){
        data[a*MATRIX_SIZE + b] = 0;
    }
}

unsigned char Filtr_prumer5(float *impuls, int delka)
{
	int a;
	float tmp[delka];

	for (a=2; a<(delka-2); a++){
		tmp[a] = (impuls[a-2] + impuls[a-1] + impuls[a] + impuls[a+1] + impuls[a+2]) / 5.0;
	}

	tmp[0] = (impuls[0] + impuls[1] + impuls[2]) / 3;
	tmp[1] = (impuls[0] + impuls[1] + impuls[2] + impuls[3]) / 4;
	tmp[delka-1] = (impuls[delka-3] + impuls[delka-2] + impuls[delka-1]) / 3;
	tmp[delka-2] = (impuls[delka-4] + impuls[delka-3] + impuls[delka-2] + impuls[delka-1]) / 4;

	for (a=0; a<delka; a++){
		impuls[a] = tmp[a];
	}

	return(0);
}

unsigned char Filtr_prumer3(float *impuls, int delka)
{
	int a;
	float tmp[delka];

	for (a=1; a<(delka-1); a++){
		tmp[a] = (impuls[a-1] + impuls[a] + impuls[a+1]) / 3.0;
	}

	tmp[0] = (impuls[0] + impuls[1] ) / 2;
	tmp[delka-1] = (impuls[delka-2] + impuls[delka-1]) / 2;

	for (a=0; a<delka; a++){
		impuls[a] = tmp[a];
	}

	return(0);
}

float Metoda_integraceDyn(float *impuls, int max, int delka)
{
	int a;
	float int1, int2, sep;
	
	#define INT_LENGTH_AFTER_MAX 150
	int limit = max + INT_LENGTH_AFTER_MAX;
	if (limit > delka) limit = delka;

	int1 = 0.0;
	int2 = 0.0;

	for (a = 0; a < limit; a++){
		if (a >= (max + 32))
		{
			int1 = int1 + impuls[a];
		}
		int2 = int2 + impuls[a];
	}

	sep = (float)(int1/int2);
	if (sep < 0)
	{
		sep = 0;
	}

	return sep * 2 * MATRIX_SIZE;
}

float Metoda_WBO(float *impuls, int max, int delka, int param)
{
	int a;
	float int1, int2, sep;

	int1 = 0.0;
	int2 = 0.0;

	for (a = 0; a < delka; a++){
		if (a >= (max + param))
		{
			int1 = int1 + impuls[a];
		}
		int2 = int2 + impuls[a];
	}

	sep = (float)(int1/int2);
	if (sep < 0)
	{
		sep = 0;
	}

	return (sep / 1.0) * (float)MATRIX_SIZE;
}

void UlozPulzDoMatice(float amplituda, float discrParam, int superponovanyPulz, int* matrix, int* x, int *y)
{
	const int mezeraNaKrajiMatice = 30;

	int DP = discrParam;
	int A = amplituda;

	if (A < 0) A = 0;
	if (DP < mezeraNaKrajiMatice) DP = mezeraNaKrajiMatice;
	if (A >= MATRIX_SIZE) A = MATRIX_SIZE - 1;
	if (DP >= MATRIX_SIZE - 3*mezeraNaKrajiMatice) DP = MATRIX_SIZE - 1 - 3*mezeraNaKrajiMatice;

	if (superponovanyPulz)
	{
		matrix[A * MATRIX_SIZE + (MATRIX_SIZE - 1 - mezeraNaKrajiMatice)]++;
	}
	else
	{
		matrix[A * MATRIX_SIZE + DP]++;
	}

	if (x != NULL) *x = A;
	if (y != NULL) *y = DP;
}


void UlozObycejneDoMatice(int amplituda, int parametr, int* matrix)
{
	int P = parametr;
	int A = amplituda;

	if (A < 0) A = 0;
	if (P < 0) P = 0;
	if (A >= MATRIX_SIZE) A = MATRIX_SIZE - 1;
	if (P >= MATRIX_SIZE - 1) P = MATRIX_SIZE - 1;

	matrix[A * MATRIX_SIZE + P]++;
}


unsigned char UlozMatici(int *data, char* nazevSouboruPartA, char* nazevSouboruPartB, char* errMsg)
{
	char nazevSouboru[100];
	sprintf(nazevSouboru, "%.50s%.50s", nazevSouboruPartA, nazevSouboruPartB);

	int a, b;
 	FILE *f;
 	unsigned long long soucet = 0;

 	f = fopen(nazevSouboru, "wb");
	if (f == NULL)
	{
		fprintf(stderr, "\nCan't open output file!\n%s\n", errMsg);
		return(0);
	}
	else
	{
		fprintf(f,"XRANGE=4095\r\n");
		fprintf(f,"YRANGE=4095\r\n");
		fprintf(f,"[DATA]\r\n");


		if (f != NULL){
			for (b=0;b<MATRIX_SIZE;b++){
				for (a=0;a<MATRIX_SIZE;a++)
				{
					if (data[(b * MATRIX_SIZE) + a]>0) {
						soucet += data[(b * MATRIX_SIZE) + a];
						fprintf(f, "%d   %d   %d\r\n", b, a, data[(b * MATRIX_SIZE) + a]);
					}
				}
			}

			fclose(f);
		}

		char* text = "Bylo ulozeno %llu impulsu do souboru %s\r\n";
		printf(text, soucet, nazevSouboru);
		fprintf(GetStatisticFile(), text, soucet, nazevSouboru);

	}


	return(1);
}

void CorrectNonlinearity(float *impuls, int delka)
{
	int i;
	for (i = 0; i < delka; i++)
	{
		int index = (int)(impuls[i]);
		if (index < 0) index = 0;
		if (index > 4095) index = 4095;

		impuls[i] -= correctionTable[(int)(impuls[i])];
	}
}


void InitCorrectionTable()
{
	int i;
	for (i = 0; i < 4096; i++)
	{
		correctionTable[i] = 0;
	}

correctionTable[	100	] = 	14	;
correctionTable[	101	] = 	14	;
correctionTable[	102	] = 	14	;
correctionTable[	103	] = 	14	;
correctionTable[	104	] = 	14	;
correctionTable[	105	] = 	14	;
correctionTable[	106	] = 	14	;
correctionTable[	107	] = 	14	;
correctionTable[	108	] = 	14	;
correctionTable[	109	] = 	14	;
correctionTable[	110	] = 	14	;
correctionTable[	111	] = 	14	;
correctionTable[	112	] = 	14	;
correctionTable[	113	] = 	14	;
correctionTable[	114	] = 	14	;
correctionTable[	115	] = 	14	;
correctionTable[	116	] = 	14	;
correctionTable[	117	] = 	14	;
correctionTable[	118	] = 	14	;
correctionTable[	119	] = 	14	;
correctionTable[	120	] = 	14	;
correctionTable[	121	] = 	14	;
correctionTable[	122	] = 	14	;
correctionTable[	123	] = 	14	;
correctionTable[	124	] = 	14	;
correctionTable[	125	] = 	14	;
correctionTable[	126	] = 	14	;
correctionTable[	127	] = 	14	;
correctionTable[	128	] = 	15	;
correctionTable[	129	] = 	15	;
correctionTable[	130	] = 	15	;
correctionTable[	131	] = 	15	;
correctionTable[	132	] = 	15	;
correctionTable[	133	] = 	15	;
correctionTable[	134	] = 	15	;
correctionTable[	135	] = 	15	;
correctionTable[	136	] = 	15	;
correctionTable[	137	] = 	15	;
correctionTable[	138	] = 	15	;
correctionTable[	139	] = 	15	;
correctionTable[	140	] = 	15	;
correctionTable[	141	] = 	15	;
correctionTable[	142	] = 	15	;
correctionTable[	143	] = 	15	;
correctionTable[	144	] = 	15	;
correctionTable[	145	] = 	15	;
correctionTable[	146	] = 	15	;
correctionTable[	147	] = 	15	;
correctionTable[	148	] = 	15	;
correctionTable[	149	] = 	15	;
correctionTable[	150	] = 	15	;
correctionTable[	151	] = 	15	;
correctionTable[	152	] = 	15	;
correctionTable[	153	] = 	15	;
correctionTable[	154	] = 	15	;
correctionTable[	155	] = 	14	;
correctionTable[	156	] = 	14	;
correctionTable[	157	] = 	14	;
correctionTable[	158	] = 	14	;
correctionTable[	159	] = 	14	;
correctionTable[	160	] = 	14	;
correctionTable[	161	] = 	14	;
correctionTable[	162	] = 	14	;
correctionTable[	163	] = 	14	;
correctionTable[	164	] = 	14	;
correctionTable[	165	] = 	14	;
correctionTable[	166	] = 	14	;
correctionTable[	167	] = 	14	;
correctionTable[	168	] = 	14	;
correctionTable[	169	] = 	14	;
correctionTable[	170	] = 	14	;
correctionTable[	171	] = 	14	;
correctionTable[	172	] = 	14	;
correctionTable[	173	] = 	14	;
correctionTable[	174	] = 	14	;
correctionTable[	175	] = 	14	;
correctionTable[	176	] = 	14	;
correctionTable[	177	] = 	14	;
correctionTable[	178	] = 	14	;
correctionTable[	179	] = 	14	;
correctionTable[	180	] = 	14	;
correctionTable[	181	] = 	14	;
correctionTable[	182	] = 	14	;
correctionTable[	183	] = 	14	;
correctionTable[	184	] = 	14	;
correctionTable[	185	] = 	14	;
correctionTable[	186	] = 	14	;
correctionTable[	187	] = 	14	;
correctionTable[	188	] = 	14	;
correctionTable[	189	] = 	14	;
correctionTable[	190	] = 	14	;
correctionTable[	191	] = 	14	;
correctionTable[	192	] = 	14	;
correctionTable[	193	] = 	14	;
correctionTable[	194	] = 	14	;
correctionTable[	195	] = 	14	;
correctionTable[	196	] = 	14	;
correctionTable[	197	] = 	14	;
correctionTable[	198	] = 	14	;
correctionTable[	199	] = 	14	;
correctionTable[	200	] = 	14	;
correctionTable[	201	] = 	14	;
correctionTable[	202	] = 	14	;
correctionTable[	203	] = 	14	;
correctionTable[	204	] = 	14	;
correctionTable[	205	] = 	14	;
correctionTable[	206	] = 	14	;
correctionTable[	207	] = 	14	;
correctionTable[	208	] = 	14	;
correctionTable[	209	] = 	14	;
correctionTable[	210	] = 	14	;
correctionTable[	211	] = 	14	;
correctionTable[	212	] = 	14	;
correctionTable[	213	] = 	14	;
correctionTable[	214	] = 	14	;
correctionTable[	215	] = 	14	;
correctionTable[	216	] = 	14	;
correctionTable[	217	] = 	14	;
correctionTable[	218	] = 	14	;
correctionTable[	219	] = 	14	;
correctionTable[	220	] = 	14	;
correctionTable[	221	] = 	14	;
correctionTable[	222	] = 	14	;
correctionTable[	223	] = 	14	;
correctionTable[	224	] = 	14	;
correctionTable[	225	] = 	14	;
correctionTable[	226	] = 	14	;
correctionTable[	227	] = 	14	;
correctionTable[	228	] = 	14	;
correctionTable[	229	] = 	14	;
correctionTable[	230	] = 	14	;
correctionTable[	231	] = 	14	;
correctionTable[	232	] = 	14	;
correctionTable[	233	] = 	14	;
correctionTable[	234	] = 	14	;
correctionTable[	235	] = 	14	;
correctionTable[	236	] = 	14	;
correctionTable[	237	] = 	14	;
correctionTable[	238	] = 	14	;
correctionTable[	239	] = 	14	;
correctionTable[	240	] = 	14	;
correctionTable[	241	] = 	14	;
correctionTable[	242	] = 	14	;
correctionTable[	243	] = 	14	;
correctionTable[	244	] = 	14	;
correctionTable[	245	] = 	14	;
correctionTable[	246	] = 	14	;
correctionTable[	247	] = 	14	;
correctionTable[	248	] = 	14	;
correctionTable[	249	] = 	14	;
correctionTable[	250	] = 	14	;
correctionTable[	251	] = 	14	;
correctionTable[	252	] = 	14	;
correctionTable[	253	] = 	14	;
correctionTable[	254	] = 	14	;
correctionTable[	255	] = 	14	;
correctionTable[	256	] = 	14	;
correctionTable[	257	] = 	14	;
correctionTable[	258	] = 	14	;
correctionTable[	259	] = 	14	;
correctionTable[	260	] = 	14	;
correctionTable[	261	] = 	14	;
correctionTable[	262	] = 	14	;
correctionTable[	263	] = 	14	;
correctionTable[	264	] = 	14	;
correctionTable[	265	] = 	14	;
correctionTable[	266	] = 	14	;
correctionTable[	267	] = 	13	;
correctionTable[	268	] = 	13	;
correctionTable[	269	] = 	13	;
correctionTable[	270	] = 	13	;
correctionTable[	271	] = 	13	;
correctionTable[	272	] = 	13	;
correctionTable[	273	] = 	13	;
correctionTable[	274	] = 	13	;
correctionTable[	275	] = 	13	;
correctionTable[	276	] = 	13	;
correctionTable[	277	] = 	13	;
correctionTable[	278	] = 	13	;
correctionTable[	279	] = 	13	;
correctionTable[	280	] = 	13	;
correctionTable[	281	] = 	13	;
correctionTable[	282	] = 	13	;
correctionTable[	283	] = 	13	;
correctionTable[	284	] = 	13	;
correctionTable[	285	] = 	13	;
correctionTable[	286	] = 	13	;
correctionTable[	287	] = 	13	;
correctionTable[	288	] = 	13	;
correctionTable[	289	] = 	13	;
correctionTable[	290	] = 	13	;
correctionTable[	291	] = 	13	;
correctionTable[	292	] = 	13	;
correctionTable[	293	] = 	13	;
correctionTable[	294	] = 	13	;
correctionTable[	295	] = 	13	;
correctionTable[	296	] = 	13	;
correctionTable[	297	] = 	13	;
correctionTable[	298	] = 	13	;
correctionTable[	299	] = 	13	;
correctionTable[	300	] = 	13	;
correctionTable[	301	] = 	13	;
correctionTable[	302	] = 	13	;
correctionTable[	303	] = 	13	;
correctionTable[	304	] = 	13	;
correctionTable[	305	] = 	13	;
correctionTable[	306	] = 	13	;
correctionTable[	307	] = 	13	;
correctionTable[	308	] = 	13	;
correctionTable[	309	] = 	13	;
correctionTable[	310	] = 	13	;
correctionTable[	311	] = 	13	;
correctionTable[	312	] = 	13	;
correctionTable[	313	] = 	13	;
correctionTable[	314	] = 	13	;
correctionTable[	315	] = 	13	;
correctionTable[	316	] = 	13	;
correctionTable[	317	] = 	13	;
correctionTable[	318	] = 	13	;
correctionTable[	319	] = 	13	;
correctionTable[	320	] = 	13	;
correctionTable[	321	] = 	13	;
correctionTable[	322	] = 	13	;
correctionTable[	323	] = 	13	;
correctionTable[	324	] = 	13	;
correctionTable[	325	] = 	13	;
correctionTable[	326	] = 	12	;
correctionTable[	327	] = 	12	;
correctionTable[	328	] = 	12	;
correctionTable[	329	] = 	12	;
correctionTable[	330	] = 	12	;
correctionTable[	331	] = 	12	;
correctionTable[	332	] = 	12	;
correctionTable[	333	] = 	12	;
correctionTable[	334	] = 	12	;
correctionTable[	335	] = 	12	;
correctionTable[	336	] = 	12	;
correctionTable[	337	] = 	12	;
correctionTable[	338	] = 	12	;
correctionTable[	339	] = 	12	;
correctionTable[	340	] = 	12	;
correctionTable[	341	] = 	12	;
correctionTable[	342	] = 	12	;
correctionTable[	343	] = 	12	;
correctionTable[	344	] = 	12	;
correctionTable[	345	] = 	12	;
correctionTable[	346	] = 	12	;
correctionTable[	347	] = 	12	;
correctionTable[	348	] = 	12	;
correctionTable[	349	] = 	12	;
correctionTable[	350	] = 	12	;
correctionTable[	351	] = 	12	;
correctionTable[	352	] = 	12	;
correctionTable[	353	] = 	12	;
correctionTable[	354	] = 	12	;
correctionTable[	355	] = 	12	;
correctionTable[	356	] = 	12	;
correctionTable[	357	] = 	12	;
correctionTable[	358	] = 	12	;
correctionTable[	359	] = 	12	;
correctionTable[	360	] = 	12	;
correctionTable[	361	] = 	12	;
correctionTable[	362	] = 	12	;
correctionTable[	363	] = 	12	;
correctionTable[	364	] = 	12	;
correctionTable[	365	] = 	12	;
correctionTable[	366	] = 	12	;
correctionTable[	367	] = 	12	;
correctionTable[	368	] = 	12	;
correctionTable[	369	] = 	12	;
correctionTable[	370	] = 	12	;
correctionTable[	371	] = 	12	;
correctionTable[	372	] = 	12	;
correctionTable[	373	] = 	12	;
correctionTable[	374	] = 	12	;
correctionTable[	375	] = 	11	;
correctionTable[	376	] = 	11	;
correctionTable[	377	] = 	11	;
correctionTable[	378	] = 	11	;
correctionTable[	379	] = 	11	;
correctionTable[	380	] = 	11	;
correctionTable[	381	] = 	11	;
correctionTable[	382	] = 	11	;
correctionTable[	383	] = 	11	;
correctionTable[	384	] = 	11	;
correctionTable[	385	] = 	11	;
correctionTable[	386	] = 	11	;
correctionTable[	387	] = 	11	;
correctionTable[	388	] = 	11	;
correctionTable[	389	] = 	11	;
correctionTable[	390	] = 	11	;
correctionTable[	391	] = 	11	;
correctionTable[	392	] = 	11	;
correctionTable[	393	] = 	11	;
correctionTable[	394	] = 	11	;
correctionTable[	395	] = 	11	;
correctionTable[	396	] = 	11	;
correctionTable[	397	] = 	11	;
correctionTable[	398	] = 	11	;
correctionTable[	399	] = 	11	;
correctionTable[	400	] = 	11	;
correctionTable[	401	] = 	11	;
correctionTable[	402	] = 	11	;
correctionTable[	403	] = 	11	;
correctionTable[	404	] = 	11	;
correctionTable[	405	] = 	11	;
correctionTable[	406	] = 	11	;
correctionTable[	407	] = 	11	;
correctionTable[	408	] = 	11	;
correctionTable[	409	] = 	11	;
correctionTable[	410	] = 	11	;
correctionTable[	411	] = 	11	;
correctionTable[	412	] = 	11	;
correctionTable[	413	] = 	11	;
correctionTable[	414	] = 	11	;
correctionTable[	415	] = 	11	;
correctionTable[	416	] = 	11	;
correctionTable[	417	] = 	11	;
correctionTable[	418	] = 	11	;
correctionTable[	419	] = 	11	;
correctionTable[	420	] = 	10	;
correctionTable[	421	] = 	10	;
correctionTable[	422	] = 	10	;
correctionTable[	423	] = 	10	;
correctionTable[	424	] = 	10	;
correctionTable[	425	] = 	10	;
correctionTable[	426	] = 	10	;
correctionTable[	427	] = 	10	;
correctionTable[	428	] = 	10	;
correctionTable[	429	] = 	10	;
correctionTable[	430	] = 	10	;
correctionTable[	431	] = 	10	;
correctionTable[	432	] = 	10	;
correctionTable[	433	] = 	10	;
correctionTable[	434	] = 	10	;
correctionTable[	435	] = 	10	;
correctionTable[	436	] = 	10	;
correctionTable[	437	] = 	10	;
correctionTable[	438	] = 	10	;
correctionTable[	439	] = 	10	;
correctionTable[	440	] = 	10	;
correctionTable[	441	] = 	10	;
correctionTable[	442	] = 	10	;
correctionTable[	443	] = 	10	;
correctionTable[	444	] = 	10	;
correctionTable[	445	] = 	10	;
correctionTable[	446	] = 	10	;
correctionTable[	447	] = 	10	;
correctionTable[	448	] = 	10	;
correctionTable[	449	] = 	10	;
correctionTable[	450	] = 	10	;
correctionTable[	451	] = 	10	;
correctionTable[	452	] = 	10	;
correctionTable[	453	] = 	10	;
correctionTable[	454	] = 	10	;
correctionTable[	455	] = 	10	;
correctionTable[	456	] = 	10	;
correctionTable[	457	] = 	10	;
correctionTable[	458	] = 	10	;
correctionTable[	459	] = 	10	;
correctionTable[	460	] = 	10	;
correctionTable[	461	] = 	10	;
correctionTable[	462	] = 	10	;
correctionTable[	463	] = 	9	;
correctionTable[	464	] = 	9	;
correctionTable[	465	] = 	9	;
correctionTable[	466	] = 	9	;
correctionTable[	467	] = 	9	;
correctionTable[	468	] = 	9	;
correctionTable[	469	] = 	9	;
correctionTable[	470	] = 	9	;
correctionTable[	471	] = 	9	;
correctionTable[	472	] = 	9	;
correctionTable[	473	] = 	9	;
correctionTable[	474	] = 	9	;
correctionTable[	475	] = 	9	;
correctionTable[	476	] = 	9	;
correctionTable[	477	] = 	9	;
correctionTable[	478	] = 	9	;
correctionTable[	479	] = 	9	;
correctionTable[	480	] = 	9	;
correctionTable[	481	] = 	9	;
correctionTable[	482	] = 	9	;
correctionTable[	483	] = 	9	;
correctionTable[	484	] = 	9	;
correctionTable[	485	] = 	9	;
correctionTable[	486	] = 	9	;
correctionTable[	487	] = 	9	;
correctionTable[	488	] = 	9	;
correctionTable[	489	] = 	9	;
correctionTable[	490	] = 	9	;
correctionTable[	491	] = 	9	;
correctionTable[	492	] = 	9	;
correctionTable[	493	] = 	9	;
correctionTable[	494	] = 	9	;
correctionTable[	495	] = 	9	;
correctionTable[	496	] = 	9	;
correctionTable[	497	] = 	9	;
correctionTable[	498	] = 	9	;
correctionTable[	499	] = 	9	;
correctionTable[	500	] = 	9	;
correctionTable[	501	] = 	9	;
correctionTable[	502	] = 	9	;
correctionTable[	503	] = 	9	;
correctionTable[	504	] = 	8	;
correctionTable[	505	] = 	8	;
correctionTable[	506	] = 	8	;
correctionTable[	507	] = 	8	;
correctionTable[	508	] = 	8	;
correctionTable[	509	] = 	8	;
correctionTable[	510	] = 	8	;
correctionTable[	511	] = 	8	;
correctionTable[	512	] = 	8	;
correctionTable[	513	] = 	8	;
correctionTable[	514	] = 	8	;
correctionTable[	515	] = 	8	;
correctionTable[	516	] = 	8	;
correctionTable[	517	] = 	8	;
correctionTable[	518	] = 	8	;
correctionTable[	519	] = 	8	;
correctionTable[	520	] = 	8	;
correctionTable[	521	] = 	8	;
correctionTable[	522	] = 	8	;
correctionTable[	523	] = 	8	;
correctionTable[	524	] = 	8	;
correctionTable[	525	] = 	8	;
correctionTable[	526	] = 	8	;
correctionTable[	527	] = 	8	;
correctionTable[	528	] = 	8	;
correctionTable[	529	] = 	8	;
correctionTable[	530	] = 	8	;
correctionTable[	531	] = 	8	;
correctionTable[	532	] = 	8	;
correctionTable[	533	] = 	8	;
correctionTable[	534	] = 	8	;
correctionTable[	535	] = 	8	;
correctionTable[	536	] = 	8	;
correctionTable[	537	] = 	8	;
correctionTable[	538	] = 	8	;
correctionTable[	539	] = 	8	;
correctionTable[	540	] = 	8	;
correctionTable[	541	] = 	8	;
correctionTable[	542	] = 	8	;
correctionTable[	543	] = 	8	;
correctionTable[	544	] = 	8	;
correctionTable[	545	] = 	7	;
correctionTable[	546	] = 	7	;
correctionTable[	547	] = 	7	;
correctionTable[	548	] = 	7	;
correctionTable[	549	] = 	7	;
correctionTable[	550	] = 	7	;
correctionTable[	551	] = 	7	;
correctionTable[	552	] = 	7	;
correctionTable[	553	] = 	7	;
correctionTable[	554	] = 	7	;
correctionTable[	555	] = 	7	;
correctionTable[	556	] = 	7	;
correctionTable[	557	] = 	7	;
correctionTable[	558	] = 	7	;
correctionTable[	559	] = 	7	;
correctionTable[	560	] = 	7	;
correctionTable[	561	] = 	7	;
correctionTable[	562	] = 	7	;
correctionTable[	563	] = 	7	;
correctionTable[	564	] = 	7	;
correctionTable[	565	] = 	7	;
correctionTable[	566	] = 	7	;
correctionTable[	567	] = 	7	;
correctionTable[	568	] = 	7	;
correctionTable[	569	] = 	7	;
correctionTable[	570	] = 	7	;
correctionTable[	571	] = 	7	;
correctionTable[	572	] = 	7	;
correctionTable[	573	] = 	7	;
correctionTable[	574	] = 	7	;
correctionTable[	575	] = 	7	;
correctionTable[	576	] = 	7	;
correctionTable[	577	] = 	7	;
correctionTable[	578	] = 	7	;
correctionTable[	579	] = 	7	;
correctionTable[	580	] = 	7	;
correctionTable[	581	] = 	7	;
correctionTable[	582	] = 	7	;
correctionTable[	583	] = 	7	;
correctionTable[	584	] = 	7	;
correctionTable[	585	] = 	7	;
correctionTable[	586	] = 	7	;
correctionTable[	587	] = 	6	;
correctionTable[	588	] = 	6	;
correctionTable[	589	] = 	6	;
correctionTable[	590	] = 	6	;
correctionTable[	591	] = 	6	;
correctionTable[	592	] = 	6	;
correctionTable[	593	] = 	6	;
correctionTable[	594	] = 	6	;
correctionTable[	595	] = 	6	;
correctionTable[	596	] = 	6	;
correctionTable[	597	] = 	6	;
correctionTable[	598	] = 	6	;
correctionTable[	599	] = 	6	;
correctionTable[	600	] = 	6	;
correctionTable[	601	] = 	6	;
correctionTable[	602	] = 	6	;
correctionTable[	603	] = 	6	;
correctionTable[	604	] = 	6	;
correctionTable[	605	] = 	6	;
correctionTable[	606	] = 	6	;
correctionTable[	607	] = 	6	;
correctionTable[	608	] = 	6	;
correctionTable[	609	] = 	6	;
correctionTable[	610	] = 	6	;
correctionTable[	611	] = 	6	;
correctionTable[	612	] = 	6	;
correctionTable[	613	] = 	6	;
correctionTable[	614	] = 	6	;
correctionTable[	615	] = 	6	;
correctionTable[	616	] = 	6	;
correctionTable[	617	] = 	6	;
correctionTable[	618	] = 	6	;
correctionTable[	619	] = 	6	;
correctionTable[	620	] = 	6	;
correctionTable[	621	] = 	6	;
correctionTable[	622	] = 	6	;
correctionTable[	623	] = 	6	;
correctionTable[	624	] = 	6	;
correctionTable[	625	] = 	6	;
correctionTable[	626	] = 	6	;
correctionTable[	627	] = 	6	;
correctionTable[	628	] = 	6	;
correctionTable[	629	] = 	5	;
correctionTable[	630	] = 	5	;
correctionTable[	631	] = 	5	;
correctionTable[	632	] = 	5	;
correctionTable[	633	] = 	5	;
correctionTable[	634	] = 	5	;
correctionTable[	635	] = 	5	;
correctionTable[	636	] = 	5	;
correctionTable[	637	] = 	5	;
correctionTable[	638	] = 	5	;
correctionTable[	639	] = 	5	;
correctionTable[	640	] = 	5	;
correctionTable[	641	] = 	5	;
correctionTable[	642	] = 	5	;
correctionTable[	643	] = 	5	;
correctionTable[	644	] = 	5	;
correctionTable[	645	] = 	5	;
correctionTable[	646	] = 	5	;
correctionTable[	647	] = 	5	;
correctionTable[	648	] = 	5	;
correctionTable[	649	] = 	5	;
correctionTable[	650	] = 	5	;
correctionTable[	651	] = 	5	;
correctionTable[	652	] = 	5	;
correctionTable[	653	] = 	5	;
correctionTable[	654	] = 	5	;
correctionTable[	655	] = 	5	;
correctionTable[	656	] = 	5	;
correctionTable[	657	] = 	5	;
correctionTable[	658	] = 	5	;
correctionTable[	659	] = 	5	;
correctionTable[	660	] = 	5	;
correctionTable[	661	] = 	5	;
correctionTable[	662	] = 	5	;
correctionTable[	663	] = 	5	;
correctionTable[	664	] = 	5	;
correctionTable[	665	] = 	5	;
correctionTable[	666	] = 	5	;
correctionTable[	667	] = 	5	;
correctionTable[	668	] = 	5	;
correctionTable[	669	] = 	5	;
correctionTable[	670	] = 	5	;
correctionTable[	671	] = 	5	;
correctionTable[	672	] = 	4	;
correctionTable[	673	] = 	4	;
correctionTable[	674	] = 	4	;
correctionTable[	675	] = 	4	;
correctionTable[	676	] = 	4	;
correctionTable[	677	] = 	4	;
correctionTable[	678	] = 	4	;
correctionTable[	679	] = 	4	;
correctionTable[	680	] = 	4	;
correctionTable[	681	] = 	4	;
correctionTable[	682	] = 	4	;
correctionTable[	683	] = 	4	;
correctionTable[	684	] = 	4	;
correctionTable[	685	] = 	4	;
correctionTable[	686	] = 	4	;
correctionTable[	687	] = 	4	;
correctionTable[	688	] = 	4	;
correctionTable[	689	] = 	4	;
correctionTable[	690	] = 	4	;
correctionTable[	691	] = 	4	;
correctionTable[	692	] = 	4	;
correctionTable[	693	] = 	4	;
correctionTable[	694	] = 	4	;
correctionTable[	695	] = 	4	;
correctionTable[	696	] = 	4	;
correctionTable[	697	] = 	4	;
correctionTable[	698	] = 	4	;
correctionTable[	699	] = 	4	;
correctionTable[	700	] = 	4	;
correctionTable[	701	] = 	4	;
correctionTable[	702	] = 	4	;
correctionTable[	703	] = 	4	;
correctionTable[	704	] = 	4	;
correctionTable[	705	] = 	4	;
correctionTable[	706	] = 	4	;
correctionTable[	707	] = 	4	;
correctionTable[	708	] = 	4	;
correctionTable[	709	] = 	4	;
correctionTable[	710	] = 	4	;
correctionTable[	711	] = 	4	;
correctionTable[	712	] = 	4	;
correctionTable[	713	] = 	4	;
correctionTable[	714	] = 	4	;
correctionTable[	715	] = 	4	;
correctionTable[	716	] = 	4	;
correctionTable[	717	] = 	3	;
correctionTable[	718	] = 	3	;
correctionTable[	719	] = 	3	;
correctionTable[	720	] = 	3	;
correctionTable[	721	] = 	3	;
correctionTable[	722	] = 	3	;
correctionTable[	723	] = 	3	;
correctionTable[	724	] = 	3	;
correctionTable[	725	] = 	3	;
correctionTable[	726	] = 	3	;
correctionTable[	727	] = 	3	;
correctionTable[	728	] = 	3	;
correctionTable[	729	] = 	3	;
correctionTable[	730	] = 	3	;
correctionTable[	731	] = 	3	;
correctionTable[	732	] = 	3	;
correctionTable[	733	] = 	3	;
correctionTable[	734	] = 	3	;
correctionTable[	735	] = 	3	;
correctionTable[	736	] = 	3	;
correctionTable[	737	] = 	3	;
correctionTable[	738	] = 	3	;
correctionTable[	739	] = 	3	;
correctionTable[	740	] = 	3	;
correctionTable[	741	] = 	3	;
correctionTable[	742	] = 	3	;
correctionTable[	743	] = 	3	;
correctionTable[	744	] = 	3	;
correctionTable[	745	] = 	3	;
correctionTable[	746	] = 	3	;
correctionTable[	747	] = 	3	;
correctionTable[	748	] = 	3	;
correctionTable[	749	] = 	3	;
correctionTable[	750	] = 	3	;
correctionTable[	751	] = 	3	;
correctionTable[	752	] = 	3	;
correctionTable[	753	] = 	3	;
correctionTable[	754	] = 	3	;
correctionTable[	755	] = 	3	;
correctionTable[	756	] = 	3	;
correctionTable[	757	] = 	3	;
correctionTable[	758	] = 	3	;
correctionTable[	759	] = 	3	;
correctionTable[	760	] = 	3	;
correctionTable[	761	] = 	3	;
correctionTable[	762	] = 	3	;
correctionTable[	763	] = 	3	;
correctionTable[	764	] = 	2	;
correctionTable[	765	] = 	2	;
correctionTable[	766	] = 	2	;
correctionTable[	767	] = 	2	;
correctionTable[	768	] = 	2	;
correctionTable[	769	] = 	2	;
correctionTable[	770	] = 	2	;
correctionTable[	771	] = 	2	;
correctionTable[	772	] = 	2	;
correctionTable[	773	] = 	2	;
correctionTable[	774	] = 	2	;
correctionTable[	775	] = 	2	;
correctionTable[	776	] = 	2	;
correctionTable[	777	] = 	2	;
correctionTable[	778	] = 	2	;
correctionTable[	779	] = 	2	;
correctionTable[	780	] = 	2	;
correctionTable[	781	] = 	2	;
correctionTable[	782	] = 	2	;
correctionTable[	783	] = 	2	;
correctionTable[	784	] = 	2	;
correctionTable[	785	] = 	2	;
correctionTable[	786	] = 	2	;
correctionTable[	787	] = 	2	;
correctionTable[	788	] = 	2	;
correctionTable[	789	] = 	2	;
correctionTable[	790	] = 	2	;
correctionTable[	791	] = 	2	;
correctionTable[	792	] = 	2	;
correctionTable[	793	] = 	2	;
correctionTable[	794	] = 	2	;
correctionTable[	795	] = 	2	;
correctionTable[	796	] = 	2	;
correctionTable[	797	] = 	2	;
correctionTable[	798	] = 	2	;
correctionTable[	799	] = 	2	;
correctionTable[	800	] = 	2	;
correctionTable[	801	] = 	2	;
correctionTable[	802	] = 	2	;
correctionTable[	803	] = 	2	;
correctionTable[	804	] = 	2	;
correctionTable[	805	] = 	2	;
correctionTable[	806	] = 	2	;
correctionTable[	807	] = 	2	;
correctionTable[	808	] = 	2	;
correctionTable[	809	] = 	2	;
correctionTable[	810	] = 	2	;
correctionTable[	811	] = 	2	;
correctionTable[	812	] = 	2	;
correctionTable[	813	] = 	2	;
correctionTable[	814	] = 	2	;
correctionTable[	815	] = 	1	;
correctionTable[	816	] = 	1	;
correctionTable[	817	] = 	1	;
correctionTable[	818	] = 	1	;
correctionTable[	819	] = 	1	;
correctionTable[	820	] = 	1	;
correctionTable[	821	] = 	1	;
correctionTable[	822	] = 	1	;
correctionTable[	823	] = 	1	;
correctionTable[	824	] = 	1	;
correctionTable[	825	] = 	1	;
correctionTable[	826	] = 	1	;
correctionTable[	827	] = 	1	;
correctionTable[	828	] = 	1	;
correctionTable[	829	] = 	1	;
correctionTable[	830	] = 	1	;
correctionTable[	831	] = 	1	;
correctionTable[	832	] = 	1	;
correctionTable[	833	] = 	1	;
correctionTable[	834	] = 	1	;
correctionTable[	835	] = 	1	;
correctionTable[	836	] = 	1	;
correctionTable[	837	] = 	1	;
correctionTable[	838	] = 	1	;
correctionTable[	839	] = 	1	;
correctionTable[	840	] = 	1	;
correctionTable[	841	] = 	1	;
correctionTable[	842	] = 	1	;
correctionTable[	843	] = 	1	;
correctionTable[	844	] = 	1	;
correctionTable[	845	] = 	1	;
correctionTable[	846	] = 	1	;
correctionTable[	847	] = 	1	;
correctionTable[	848	] = 	1	;
correctionTable[	849	] = 	1	;
correctionTable[	850	] = 	1	;
correctionTable[	851	] = 	1	;
correctionTable[	852	] = 	1	;
correctionTable[	853	] = 	1	;
correctionTable[	854	] = 	1	;
correctionTable[	855	] = 	1	;
correctionTable[	856	] = 	1	;
correctionTable[	857	] = 	1	;
correctionTable[	858	] = 	1	;
correctionTable[	859	] = 	1	;
correctionTable[	860	] = 	1	;
correctionTable[	861	] = 	1	;
correctionTable[	862	] = 	1	;
correctionTable[	863	] = 	1	;
correctionTable[	864	] = 	1	;
correctionTable[	865	] = 	1	;
correctionTable[	866	] = 	1	;
correctionTable[	867	] = 	1	;
correctionTable[	868	] = 	1	;
correctionTable[	869	] = 	1	;
correctionTable[	870	] = 	1	;
correctionTable[	871	] = 	0	;
correctionTable[	872	] = 	0	;
correctionTable[	873	] = 	0	;
correctionTable[	874	] = 	0	;
correctionTable[	875	] = 	0	;
correctionTable[	876	] = 	0	;
correctionTable[	877	] = 	0	;
correctionTable[	878	] = 	0	;
correctionTable[	879	] = 	0	;
correctionTable[	880	] = 	0	;
correctionTable[	881	] = 	0	;
correctionTable[	882	] = 	0	;
correctionTable[	883	] = 	0	;
correctionTable[	884	] = 	0	;
correctionTable[	885	] = 	0	;
correctionTable[	886	] = 	0	;
correctionTable[	887	] = 	0	;
correctionTable[	888	] = 	0	;
correctionTable[	889	] = 	0	;
correctionTable[	890	] = 	0	;
correctionTable[	891	] = 	0	;
correctionTable[	892	] = 	0	;
correctionTable[	893	] = 	0	;
correctionTable[	894	] = 	0	;
correctionTable[	895	] = 	0	;
correctionTable[	896	] = 	0	;
correctionTable[	897	] = 	0	;
correctionTable[	898	] = 	0	;
correctionTable[	899	] = 	0	;
correctionTable[	900	] = 	0	;
correctionTable[	901	] = 	0	;
correctionTable[	902	] = 	0	;
correctionTable[	903	] = 	0	;
correctionTable[	904	] = 	0	;
correctionTable[	905	] = 	0	;
correctionTable[	906	] = 	0	;
correctionTable[	907	] = 	0	;
correctionTable[	908	] = 	0	;
correctionTable[	909	] = 	0	;
correctionTable[	910	] = 	0	;
correctionTable[	911	] = 	0	;
correctionTable[	912	] = 	0	;
correctionTable[	913	] = 	0	;
correctionTable[	914	] = 	0	;
correctionTable[	915	] = 	0	;
correctionTable[	916	] = 	0	;
correctionTable[	917	] = 	0	;
correctionTable[	918	] = 	0	;
correctionTable[	919	] = 	0	;
correctionTable[	920	] = 	0	;
correctionTable[	921	] = 	0	;
correctionTable[	922	] = 	0	;
correctionTable[	923	] = 	0	;
correctionTable[	924	] = 	0	;
correctionTable[	925	] = 	0	;
correctionTable[	926	] = 	0	;
correctionTable[	927	] = 	0	;
correctionTable[	928	] = 	0	;
correctionTable[	929	] = 	0	;
correctionTable[	930	] = 	0	;
correctionTable[	931	] = 	0	;
correctionTable[	932	] = 	-1	;
correctionTable[	933	] = 	-1	;
correctionTable[	934	] = 	-1	;
correctionTable[	935	] = 	-1	;
correctionTable[	936	] = 	-1	;
correctionTable[	937	] = 	-1	;
correctionTable[	938	] = 	-1	;
correctionTable[	939	] = 	-1	;
correctionTable[	940	] = 	-1	;
correctionTable[	941	] = 	-1	;
correctionTable[	942	] = 	-1	;
correctionTable[	943	] = 	-1	;
correctionTable[	944	] = 	-1	;
correctionTable[	945	] = 	-1	;
correctionTable[	946	] = 	-1	;
correctionTable[	947	] = 	-1	;
correctionTable[	948	] = 	-1	;
correctionTable[	949	] = 	-1	;
correctionTable[	950	] = 	-1	;
correctionTable[	951	] = 	-1	;
correctionTable[	952	] = 	-1	;
correctionTable[	953	] = 	-1	;
correctionTable[	954	] = 	-1	;
correctionTable[	955	] = 	-1	;
correctionTable[	956	] = 	-1	;
correctionTable[	957	] = 	-1	;
correctionTable[	958	] = 	-1	;
correctionTable[	959	] = 	-1	;
correctionTable[	960	] = 	-1	;
correctionTable[	961	] = 	-1	;
correctionTable[	962	] = 	-1	;
correctionTable[	963	] = 	-1	;
correctionTable[	964	] = 	-1	;
correctionTable[	965	] = 	-1	;
correctionTable[	966	] = 	-1	;
correctionTable[	967	] = 	-1	;
correctionTable[	968	] = 	-1	;
correctionTable[	969	] = 	-1	;
correctionTable[	970	] = 	-1	;
correctionTable[	971	] = 	-1	;
correctionTable[	972	] = 	-1	;
correctionTable[	973	] = 	-1	;
correctionTable[	974	] = 	-1	;
correctionTable[	975	] = 	-1	;
correctionTable[	976	] = 	-1	;
correctionTable[	977	] = 	-1	;
correctionTable[	978	] = 	-1	;
correctionTable[	979	] = 	-1	;
correctionTable[	980	] = 	-1	;
correctionTable[	981	] = 	-1	;
correctionTable[	982	] = 	-1	;
correctionTable[	983	] = 	-1	;
correctionTable[	984	] = 	-1	;
correctionTable[	985	] = 	-1	;
correctionTable[	986	] = 	-1	;
correctionTable[	987	] = 	-1	;
correctionTable[	988	] = 	-1	;
correctionTable[	989	] = 	-1	;
correctionTable[	990	] = 	-1	;
correctionTable[	991	] = 	-1	;
correctionTable[	992	] = 	-1	;
correctionTable[	993	] = 	-1	;
correctionTable[	994	] = 	-1	;
correctionTable[	995	] = 	-1	;
correctionTable[	996	] = 	-1	;
correctionTable[	997	] = 	-1	;
correctionTable[	998	] = 	-1	;
correctionTable[	999	] = 	-1	;
correctionTable[	1000	] = 	-1	;
correctionTable[	1001	] = 	-1	;
correctionTable[	1002	] = 	-1	;
correctionTable[	1003	] = 	-2	;
correctionTable[	1004	] = 	-2	;
correctionTable[	1005	] = 	-2	;
correctionTable[	1006	] = 	-2	;
correctionTable[	1007	] = 	-2	;
correctionTable[	1008	] = 	-2	;
correctionTable[	1009	] = 	-2	;
correctionTable[	1010	] = 	-2	;
correctionTable[	1011	] = 	-2	;
correctionTable[	1012	] = 	-2	;
correctionTable[	1013	] = 	-2	;
correctionTable[	1014	] = 	-2	;
correctionTable[	1015	] = 	-2	;
correctionTable[	1016	] = 	-2	;
correctionTable[	1017	] = 	-2	;
correctionTable[	1018	] = 	-2	;
correctionTable[	1019	] = 	-2	;
correctionTable[	1020	] = 	-2	;
correctionTable[	1021	] = 	-2	;
correctionTable[	1022	] = 	-2	;
correctionTable[	1023	] = 	-2	;
correctionTable[	1024	] = 	-2	;
correctionTable[	1025	] = 	-2	;
correctionTable[	1026	] = 	-2	;
correctionTable[	1027	] = 	-2	;
correctionTable[	1028	] = 	-2	;
correctionTable[	1029	] = 	-2	;
correctionTable[	1030	] = 	-2	;
correctionTable[	1031	] = 	-2	;
correctionTable[	1032	] = 	-2	;
correctionTable[	1033	] = 	-2	;
correctionTable[	1034	] = 	-2	;
correctionTable[	1035	] = 	-2	;
correctionTable[	1036	] = 	-2	;
correctionTable[	1037	] = 	-2	;
correctionTable[	1038	] = 	-2	;
correctionTable[	1039	] = 	-2	;
correctionTable[	1040	] = 	-2	;
correctionTable[	1041	] = 	-2	;
correctionTable[	1042	] = 	-2	;
correctionTable[	1043	] = 	-2	;
correctionTable[	1044	] = 	-2	;
correctionTable[	1045	] = 	-2	;
correctionTable[	1046	] = 	-2	;
correctionTable[	1047	] = 	-2	;
correctionTable[	1048	] = 	-2	;
correctionTable[	1049	] = 	-2	;
correctionTable[	1050	] = 	-2	;
correctionTable[	1051	] = 	-2	;
correctionTable[	1052	] = 	-2	;
correctionTable[	1053	] = 	-2	;
correctionTable[	1054	] = 	-2	;
correctionTable[	1055	] = 	-2	;
correctionTable[	1056	] = 	-2	;
correctionTable[	1057	] = 	-2	;
correctionTable[	1058	] = 	-2	;
correctionTable[	1059	] = 	-2	;
correctionTable[	1060	] = 	-2	;
correctionTable[	1061	] = 	-2	;
correctionTable[	1062	] = 	-2	;
correctionTable[	1063	] = 	-2	;
correctionTable[	1064	] = 	-2	;
correctionTable[	1065	] = 	-2	;
correctionTable[	1066	] = 	-2	;
correctionTable[	1067	] = 	-2	;
correctionTable[	1068	] = 	-2	;
correctionTable[	1069	] = 	-2	;
correctionTable[	1070	] = 	-2	;
correctionTable[	1071	] = 	-2	;
correctionTable[	1072	] = 	-2	;
correctionTable[	1073	] = 	-2	;
correctionTable[	1074	] = 	-2	;
correctionTable[	1075	] = 	-2	;
correctionTable[	1076	] = 	-2	;
correctionTable[	1077	] = 	-2	;
correctionTable[	1078	] = 	-2	;
correctionTable[	1079	] = 	-2	;
correctionTable[	1080	] = 	-2	;
correctionTable[	1081	] = 	-2	;
correctionTable[	1082	] = 	-2	;
correctionTable[	1083	] = 	-2	;
correctionTable[	1084	] = 	-2	;
correctionTable[	1085	] = 	-2	;
correctionTable[	1086	] = 	-3	;
correctionTable[	1087	] = 	-3	;
correctionTable[	1088	] = 	-3	;
correctionTable[	1089	] = 	-3	;
correctionTable[	1090	] = 	-3	;
correctionTable[	1091	] = 	-3	;
correctionTable[	1092	] = 	-3	;
correctionTable[	1093	] = 	-3	;
correctionTable[	1094	] = 	-3	;
correctionTable[	1095	] = 	-3	;
correctionTable[	1096	] = 	-3	;
correctionTable[	1097	] = 	-3	;
correctionTable[	1098	] = 	-3	;
correctionTable[	1099	] = 	-3	;
correctionTable[	1100	] = 	-3	;
correctionTable[	1101	] = 	-3	;
correctionTable[	1102	] = 	-3	;
correctionTable[	1103	] = 	-3	;
correctionTable[	1104	] = 	-3	;
correctionTable[	1105	] = 	-3	;
correctionTable[	1106	] = 	-3	;
correctionTable[	1107	] = 	-3	;
correctionTable[	1108	] = 	-3	;
correctionTable[	1109	] = 	-3	;
correctionTable[	1110	] = 	-3	;
correctionTable[	1111	] = 	-3	;
correctionTable[	1112	] = 	-3	;
correctionTable[	1113	] = 	-3	;
correctionTable[	1114	] = 	-3	;
correctionTable[	1115	] = 	-3	;
correctionTable[	1116	] = 	-3	;
correctionTable[	1117	] = 	-3	;
correctionTable[	1118	] = 	-3	;
correctionTable[	1119	] = 	-3	;
correctionTable[	1120	] = 	-3	;
correctionTable[	1121	] = 	-3	;
correctionTable[	1122	] = 	-3	;
correctionTable[	1123	] = 	-3	;
correctionTable[	1124	] = 	-3	;
correctionTable[	1125	] = 	-3	;
correctionTable[	1126	] = 	-3	;
correctionTable[	1127	] = 	-3	;
correctionTable[	1128	] = 	-3	;
correctionTable[	1129	] = 	-3	;
correctionTable[	1130	] = 	-3	;
correctionTable[	1131	] = 	-3	;
correctionTable[	1132	] = 	-3	;
correctionTable[	1133	] = 	-3	;
correctionTable[	1134	] = 	-3	;
correctionTable[	1135	] = 	-3	;
correctionTable[	1136	] = 	-3	;
correctionTable[	1137	] = 	-3	;
correctionTable[	1138	] = 	-3	;
correctionTable[	1139	] = 	-3	;
correctionTable[	1140	] = 	-3	;
correctionTable[	1141	] = 	-3	;
correctionTable[	1142	] = 	-3	;
correctionTable[	1143	] = 	-3	;
correctionTable[	1144	] = 	-3	;
correctionTable[	1145	] = 	-3	;
correctionTable[	1146	] = 	-3	;
correctionTable[	1147	] = 	-3	;
correctionTable[	1148	] = 	-3	;
correctionTable[	1149	] = 	-3	;
correctionTable[	1150	] = 	-3	;
correctionTable[	1151	] = 	-3	;
correctionTable[	1152	] = 	-3	;
correctionTable[	1153	] = 	-3	;
correctionTable[	1154	] = 	-3	;
correctionTable[	1155	] = 	-3	;
correctionTable[	1156	] = 	-3	;
correctionTable[	1157	] = 	-3	;
correctionTable[	1158	] = 	-3	;
correctionTable[	1159	] = 	-3	;
correctionTable[	1160	] = 	-3	;
correctionTable[	1161	] = 	-3	;
correctionTable[	1162	] = 	-3	;
correctionTable[	1163	] = 	-3	;
correctionTable[	1164	] = 	-3	;
correctionTable[	1165	] = 	-3	;
correctionTable[	1166	] = 	-3	;
correctionTable[	1167	] = 	-3	;
correctionTable[	1168	] = 	-3	;
correctionTable[	1169	] = 	-3	;
correctionTable[	1170	] = 	-3	;
correctionTable[	1171	] = 	-3	;
correctionTable[	1172	] = 	-3	;
correctionTable[	1173	] = 	-3	;
correctionTable[	1174	] = 	-3	;
correctionTable[	1175	] = 	-3	;
correctionTable[	1176	] = 	-3	;
correctionTable[	1177	] = 	-3	;
correctionTable[	1178	] = 	-3	;
correctionTable[	1179	] = 	-3	;
correctionTable[	1180	] = 	-3	;
correctionTable[	1181	] = 	-3	;
correctionTable[	1182	] = 	-3	;
correctionTable[	1183	] = 	-3	;
correctionTable[	1184	] = 	-3	;
correctionTable[	1185	] = 	-3	;
correctionTable[	1186	] = 	-3	;
correctionTable[	1187	] = 	-3	;
correctionTable[	1188	] = 	-3	;
correctionTable[	1189	] = 	-4	;
correctionTable[	1190	] = 	-4	;
correctionTable[	1191	] = 	-4	;
correctionTable[	1192	] = 	-4	;
correctionTable[	1193	] = 	-4	;
correctionTable[	1194	] = 	-4	;
correctionTable[	1195	] = 	-4	;
correctionTable[	1196	] = 	-4	;
correctionTable[	1197	] = 	-4	;
correctionTable[	1198	] = 	-4	;
correctionTable[	1199	] = 	-4	;
correctionTable[	1200	] = 	-4	;
correctionTable[	1201	] = 	-4	;
correctionTable[	1202	] = 	-4	;
correctionTable[	1203	] = 	-4	;
correctionTable[	1204	] = 	-4	;
correctionTable[	1205	] = 	-4	;
correctionTable[	1206	] = 	-4	;
correctionTable[	1207	] = 	-4	;
correctionTable[	1208	] = 	-4	;
correctionTable[	1209	] = 	-4	;
correctionTable[	1210	] = 	-4	;
correctionTable[	1211	] = 	-4	;
correctionTable[	1212	] = 	-4	;
correctionTable[	1213	] = 	-4	;
correctionTable[	1214	] = 	-4	;
correctionTable[	1215	] = 	-4	;
correctionTable[	1216	] = 	-4	;
correctionTable[	1217	] = 	-4	;
correctionTable[	1218	] = 	-4	;
correctionTable[	1219	] = 	-4	;
correctionTable[	1220	] = 	-4	;
correctionTable[	1221	] = 	-4	;
correctionTable[	1222	] = 	-4	;
correctionTable[	1223	] = 	-4	;
correctionTable[	1224	] = 	-4	;
correctionTable[	1225	] = 	-4	;
correctionTable[	1226	] = 	-4	;
correctionTable[	1227	] = 	-4	;
correctionTable[	1228	] = 	-4	;
correctionTable[	1229	] = 	-4	;
correctionTable[	1230	] = 	-4	;
correctionTable[	1231	] = 	-4	;
correctionTable[	1232	] = 	-4	;
correctionTable[	1233	] = 	-4	;
correctionTable[	1234	] = 	-4	;
correctionTable[	1235	] = 	-4	;
correctionTable[	1236	] = 	-4	;
correctionTable[	1237	] = 	-4	;
correctionTable[	1238	] = 	-4	;
correctionTable[	1239	] = 	-4	;
correctionTable[	1240	] = 	-4	;
correctionTable[	1241	] = 	-4	;
correctionTable[	1242	] = 	-4	;
correctionTable[	1243	] = 	-4	;
correctionTable[	1244	] = 	-4	;
correctionTable[	1245	] = 	-4	;
correctionTable[	1246	] = 	-4	;
correctionTable[	1247	] = 	-4	;
correctionTable[	1248	] = 	-4	;
correctionTable[	1249	] = 	-4	;
correctionTable[	1250	] = 	-4	;
correctionTable[	1251	] = 	-4	;
correctionTable[	1252	] = 	-4	;
correctionTable[	1253	] = 	-4	;
correctionTable[	1254	] = 	-4	;
correctionTable[	1255	] = 	-4	;
correctionTable[	1256	] = 	-4	;
correctionTable[	1257	] = 	-4	;
correctionTable[	1258	] = 	-4	;
correctionTable[	1259	] = 	-4	;
correctionTable[	1260	] = 	-4	;
correctionTable[	1261	] = 	-4	;
correctionTable[	1262	] = 	-4	;
correctionTable[	1263	] = 	-4	;
correctionTable[	1264	] = 	-4	;
correctionTable[	1265	] = 	-4	;
correctionTable[	1266	] = 	-4	;
correctionTable[	1267	] = 	-4	;
correctionTable[	1268	] = 	-4	;
correctionTable[	1269	] = 	-4	;
correctionTable[	1270	] = 	-4	;
correctionTable[	1271	] = 	-4	;
correctionTable[	1272	] = 	-4	;
correctionTable[	1273	] = 	-4	;
correctionTable[	1274	] = 	-4	;
correctionTable[	1275	] = 	-4	;
correctionTable[	1276	] = 	-4	;
correctionTable[	1277	] = 	-4	;
correctionTable[	1278	] = 	-4	;
correctionTable[	1279	] = 	-4	;
correctionTable[	1280	] = 	-4	;
correctionTable[	1281	] = 	-4	;
correctionTable[	1282	] = 	-4	;
correctionTable[	1283	] = 	-4	;
correctionTable[	1284	] = 	-4	;
correctionTable[	1285	] = 	-4	;
correctionTable[	1286	] = 	-4	;
correctionTable[	1287	] = 	-4	;
correctionTable[	1288	] = 	-4	;
correctionTable[	1289	] = 	-4	;
correctionTable[	1290	] = 	-4	;
correctionTable[	1291	] = 	-4	;
correctionTable[	1292	] = 	-4	;
correctionTable[	1293	] = 	-4	;
correctionTable[	1294	] = 	-4	;
correctionTable[	1295	] = 	-4	;
correctionTable[	1296	] = 	-4	;
correctionTable[	1297	] = 	-4	;
correctionTable[	1298	] = 	-4	;
correctionTable[	1299	] = 	-4	;
correctionTable[	1300	] = 	-4	;
correctionTable[	1301	] = 	-4	;
correctionTable[	1302	] = 	-4	;
correctionTable[	1303	] = 	-4	;
correctionTable[	1304	] = 	-4	;
correctionTable[	1305	] = 	-4	;
correctionTable[	1306	] = 	-4	;
correctionTable[	1307	] = 	-4	;
correctionTable[	1308	] = 	-4	;
correctionTable[	1309	] = 	-4	;
correctionTable[	1310	] = 	-4	;
correctionTable[	1311	] = 	-4	;
correctionTable[	1312	] = 	-4	;
correctionTable[	1313	] = 	-4	;
correctionTable[	1314	] = 	-4	;
correctionTable[	1315	] = 	-4	;
correctionTable[	1316	] = 	-4	;
correctionTable[	1317	] = 	-4	;
correctionTable[	1318	] = 	-4	;
correctionTable[	1319	] = 	-4	;
correctionTable[	1320	] = 	-4	;
correctionTable[	1321	] = 	-4	;
correctionTable[	1322	] = 	-4	;
correctionTable[	1323	] = 	-5	;
correctionTable[	1324	] = 	-5	;
correctionTable[	1325	] = 	-5	;
correctionTable[	1326	] = 	-5	;
correctionTable[	1327	] = 	-5	;
correctionTable[	1328	] = 	-5	;
correctionTable[	1329	] = 	-5	;
correctionTable[	1330	] = 	-5	;
correctionTable[	1331	] = 	-5	;
correctionTable[	1332	] = 	-5	;
correctionTable[	1333	] = 	-5	;
correctionTable[	1334	] = 	-5	;
correctionTable[	1335	] = 	-5	;
correctionTable[	1336	] = 	-5	;
correctionTable[	1337	] = 	-5	;
correctionTable[	1338	] = 	-5	;
correctionTable[	1339	] = 	-5	;
correctionTable[	1340	] = 	-5	;
correctionTable[	1341	] = 	-5	;
correctionTable[	1342	] = 	-5	;
correctionTable[	1343	] = 	-5	;
correctionTable[	1344	] = 	-5	;
correctionTable[	1345	] = 	-5	;
correctionTable[	1346	] = 	-5	;
correctionTable[	1347	] = 	-5	;
correctionTable[	1348	] = 	-5	;
correctionTable[	1349	] = 	-5	;
correctionTable[	1350	] = 	-5	;
correctionTable[	1351	] = 	-5	;
correctionTable[	1352	] = 	-5	;
correctionTable[	1353	] = 	-5	;
correctionTable[	1354	] = 	-5	;
correctionTable[	1355	] = 	-5	;
correctionTable[	1356	] = 	-5	;
correctionTable[	1357	] = 	-5	;
correctionTable[	1358	] = 	-5	;
correctionTable[	1359	] = 	-5	;
correctionTable[	1360	] = 	-5	;
correctionTable[	1361	] = 	-5	;
correctionTable[	1362	] = 	-5	;
correctionTable[	1363	] = 	-5	;
correctionTable[	1364	] = 	-5	;
correctionTable[	1365	] = 	-5	;
correctionTable[	1366	] = 	-5	;
correctionTable[	1367	] = 	-5	;
correctionTable[	1368	] = 	-5	;
correctionTable[	1369	] = 	-5	;
correctionTable[	1370	] = 	-5	;
correctionTable[	1371	] = 	-5	;
correctionTable[	1372	] = 	-5	;
correctionTable[	1373	] = 	-5	;
correctionTable[	1374	] = 	-5	;
correctionTable[	1375	] = 	-5	;
correctionTable[	1376	] = 	-5	;
correctionTable[	1377	] = 	-5	;
correctionTable[	1378	] = 	-5	;
correctionTable[	1379	] = 	-5	;
correctionTable[	1380	] = 	-5	;
correctionTable[	1381	] = 	-5	;
correctionTable[	1382	] = 	-5	;
correctionTable[	1383	] = 	-5	;
correctionTable[	1384	] = 	-5	;
correctionTable[	1385	] = 	-5	;
correctionTable[	1386	] = 	-5	;
correctionTable[	1387	] = 	-5	;
correctionTable[	1388	] = 	-5	;
correctionTable[	1389	] = 	-5	;
correctionTable[	1390	] = 	-5	;
correctionTable[	1391	] = 	-5	;
correctionTable[	1392	] = 	-5	;
correctionTable[	1393	] = 	-5	;
correctionTable[	1394	] = 	-5	;
correctionTable[	1395	] = 	-5	;
correctionTable[	1396	] = 	-5	;
correctionTable[	1397	] = 	-5	;
correctionTable[	1398	] = 	-5	;
correctionTable[	1399	] = 	-5	;
correctionTable[	1400	] = 	-5	;
correctionTable[	1401	] = 	-5	;
correctionTable[	1402	] = 	-5	;
correctionTable[	1403	] = 	-5	;
correctionTable[	1404	] = 	-5	;
correctionTable[	1405	] = 	-5	;
correctionTable[	1406	] = 	-5	;
correctionTable[	1407	] = 	-5	;
correctionTable[	1408	] = 	-5	;
correctionTable[	1409	] = 	-5	;
correctionTable[	1410	] = 	-5	;
correctionTable[	1411	] = 	-5	;
correctionTable[	1412	] = 	-5	;
correctionTable[	1413	] = 	-5	;
correctionTable[	1414	] = 	-5	;
correctionTable[	1415	] = 	-5	;
correctionTable[	1416	] = 	-5	;
correctionTable[	1417	] = 	-5	;
correctionTable[	1418	] = 	-5	;
correctionTable[	1419	] = 	-5	;
correctionTable[	1420	] = 	-5	;
correctionTable[	1421	] = 	-5	;
correctionTable[	1422	] = 	-5	;
correctionTable[	1423	] = 	-5	;
correctionTable[	1424	] = 	-5	;
correctionTable[	1425	] = 	-5	;
correctionTable[	1426	] = 	-5	;
correctionTable[	1427	] = 	-5	;
correctionTable[	1428	] = 	-5	;
correctionTable[	1429	] = 	-5	;
correctionTable[	1430	] = 	-5	;
correctionTable[	1431	] = 	-5	;
correctionTable[	1432	] = 	-5	;
correctionTable[	1433	] = 	-5	;
correctionTable[	1434	] = 	-5	;
correctionTable[	1435	] = 	-5	;
correctionTable[	1436	] = 	-5	;
correctionTable[	1437	] = 	-5	;
correctionTable[	1438	] = 	-5	;
correctionTable[	1439	] = 	-5	;
correctionTable[	1440	] = 	-5	;
correctionTable[	1441	] = 	-5	;
correctionTable[	1442	] = 	-5	;
correctionTable[	1443	] = 	-5	;
correctionTable[	1444	] = 	-5	;
correctionTable[	1445	] = 	-5	;
correctionTable[	1446	] = 	-5	;
correctionTable[	1447	] = 	-5	;
correctionTable[	1448	] = 	-5	;
correctionTable[	1449	] = 	-5	;
correctionTable[	1450	] = 	-5	;
correctionTable[	1451	] = 	-5	;
correctionTable[	1452	] = 	-5	;
correctionTable[	1453	] = 	-5	;
correctionTable[	1454	] = 	-5	;
correctionTable[	1455	] = 	-5	;
correctionTable[	1456	] = 	-5	;
correctionTable[	1457	] = 	-5	;
correctionTable[	1458	] = 	-5	;
correctionTable[	1459	] = 	-5	;
correctionTable[	1460	] = 	-5	;
correctionTable[	1461	] = 	-5	;
correctionTable[	1462	] = 	-5	;
correctionTable[	1463	] = 	-5	;
correctionTable[	1464	] = 	-5	;
correctionTable[	1465	] = 	-5	;
correctionTable[	1466	] = 	-5	;
correctionTable[	1467	] = 	-5	;
correctionTable[	1468	] = 	-5	;
correctionTable[	1469	] = 	-5	;
correctionTable[	1470	] = 	-5	;
correctionTable[	1471	] = 	-5	;
correctionTable[	1472	] = 	-5	;
correctionTable[	1473	] = 	-5	;
correctionTable[	1474	] = 	-5	;
correctionTable[	1475	] = 	-5	;
correctionTable[	1476	] = 	-5	;
correctionTable[	1477	] = 	-5	;
correctionTable[	1478	] = 	-5	;
correctionTable[	1479	] = 	-5	;
correctionTable[	1480	] = 	-5	;
correctionTable[	1481	] = 	-5	;
correctionTable[	1482	] = 	-5	;
correctionTable[	1483	] = 	-5	;
correctionTable[	1484	] = 	-5	;
correctionTable[	1485	] = 	-5	;
correctionTable[	1486	] = 	-5	;
correctionTable[	1487	] = 	-5	;
correctionTable[	1488	] = 	-5	;
correctionTable[	1489	] = 	-5	;
correctionTable[	1490	] = 	-5	;
correctionTable[	1491	] = 	-5	;
correctionTable[	1492	] = 	-5	;
correctionTable[	1493	] = 	-6	;
correctionTable[	1494	] = 	-6	;
correctionTable[	1495	] = 	-6	;
correctionTable[	1496	] = 	-6	;
correctionTable[	1497	] = 	-6	;
correctionTable[	1498	] = 	-6	;
correctionTable[	1499	] = 	-6	;
correctionTable[	1500	] = 	-6	;
correctionTable[	1501	] = 	-6	;
correctionTable[	1502	] = 	-6	;
correctionTable[	1503	] = 	-6	;
correctionTable[	1504	] = 	-6	;
correctionTable[	1505	] = 	-6	;
correctionTable[	1506	] = 	-6	;
correctionTable[	1507	] = 	-6	;
correctionTable[	1508	] = 	-6	;
correctionTable[	1509	] = 	-6	;
correctionTable[	1510	] = 	-6	;
correctionTable[	1511	] = 	-6	;
correctionTable[	1512	] = 	-6	;
correctionTable[	1513	] = 	-6	;
correctionTable[	1514	] = 	-6	;
correctionTable[	1515	] = 	-6	;
correctionTable[	1516	] = 	-6	;
correctionTable[	1517	] = 	-6	;
correctionTable[	1518	] = 	-6	;
correctionTable[	1519	] = 	-6	;
correctionTable[	1520	] = 	-6	;
correctionTable[	1521	] = 	-6	;
correctionTable[	1522	] = 	-6	;
correctionTable[	1523	] = 	-6	;
correctionTable[	1524	] = 	-6	;
correctionTable[	1525	] = 	-6	;
correctionTable[	1526	] = 	-6	;
correctionTable[	1527	] = 	-6	;
correctionTable[	1528	] = 	-6	;
correctionTable[	1529	] = 	-6	;
correctionTable[	1530	] = 	-6	;
correctionTable[	1531	] = 	-6	;
correctionTable[	1532	] = 	-6	;
correctionTable[	1533	] = 	-6	;
correctionTable[	1534	] = 	-6	;
correctionTable[	1535	] = 	-6	;
correctionTable[	1536	] = 	-6	;
correctionTable[	1537	] = 	-6	;
correctionTable[	1538	] = 	-6	;
correctionTable[	1539	] = 	-6	;
correctionTable[	1540	] = 	-6	;
correctionTable[	1541	] = 	-6	;
correctionTable[	1542	] = 	-6	;
correctionTable[	1543	] = 	-6	;
correctionTable[	1544	] = 	-6	;
correctionTable[	1545	] = 	-6	;
correctionTable[	1546	] = 	-6	;
correctionTable[	1547	] = 	-6	;
correctionTable[	1548	] = 	-6	;
correctionTable[	1549	] = 	-6	;
correctionTable[	1550	] = 	-6	;
correctionTable[	1551	] = 	-6	;
correctionTable[	1552	] = 	-6	;
correctionTable[	1553	] = 	-6	;
correctionTable[	1554	] = 	-6	;
correctionTable[	1555	] = 	-6	;
correctionTable[	1556	] = 	-6	;
correctionTable[	1557	] = 	-6	;
correctionTable[	1558	] = 	-6	;
correctionTable[	1559	] = 	-6	;
correctionTable[	1560	] = 	-6	;
correctionTable[	1561	] = 	-6	;
correctionTable[	1562	] = 	-6	;
correctionTable[	1563	] = 	-6	;
correctionTable[	1564	] = 	-6	;
correctionTable[	1565	] = 	-6	;
correctionTable[	1566	] = 	-6	;
correctionTable[	1567	] = 	-6	;
correctionTable[	1568	] = 	-6	;
correctionTable[	1569	] = 	-6	;
correctionTable[	1570	] = 	-6	;
correctionTable[	1571	] = 	-6	;
correctionTable[	1572	] = 	-6	;
correctionTable[	1573	] = 	-6	;
correctionTable[	1574	] = 	-6	;
correctionTable[	1575	] = 	-6	;
correctionTable[	1576	] = 	-6	;
correctionTable[	1577	] = 	-6	;
correctionTable[	1578	] = 	-6	;
correctionTable[	1579	] = 	-6	;
correctionTable[	1580	] = 	-6	;
correctionTable[	1581	] = 	-6	;
correctionTable[	1582	] = 	-6	;
correctionTable[	1583	] = 	-6	;
correctionTable[	1584	] = 	-6	;
correctionTable[	1585	] = 	-6	;
correctionTable[	1586	] = 	-6	;
correctionTable[	1587	] = 	-6	;
correctionTable[	1588	] = 	-6	;
correctionTable[	1589	] = 	-6	;
correctionTable[	1590	] = 	-6	;
correctionTable[	1591	] = 	-6	;
correctionTable[	1592	] = 	-6	;
correctionTable[	1593	] = 	-6	;
correctionTable[	1594	] = 	-6	;
correctionTable[	1595	] = 	-6	;
correctionTable[	1596	] = 	-6	;
correctionTable[	1597	] = 	-6	;
correctionTable[	1598	] = 	-6	;
correctionTable[	1599	] = 	-6	;
correctionTable[	1600	] = 	-6	;
correctionTable[	1601	] = 	-6	;
correctionTable[	1602	] = 	-6	;
correctionTable[	1603	] = 	-6	;
correctionTable[	1604	] = 	-6	;
correctionTable[	1605	] = 	-6	;
correctionTable[	1606	] = 	-6	;
correctionTable[	1607	] = 	-6	;
correctionTable[	1608	] = 	-6	;
correctionTable[	1609	] = 	-6	;
correctionTable[	1610	] = 	-6	;
correctionTable[	1611	] = 	-6	;
correctionTable[	1612	] = 	-6	;
correctionTable[	1613	] = 	-6	;
correctionTable[	1614	] = 	-6	;
correctionTable[	1615	] = 	-6	;
correctionTable[	1616	] = 	-6	;
correctionTable[	1617	] = 	-6	;
correctionTable[	1618	] = 	-6	;
correctionTable[	1619	] = 	-6	;
correctionTable[	1620	] = 	-6	;
correctionTable[	1621	] = 	-6	;
correctionTable[	1622	] = 	-6	;
correctionTable[	1623	] = 	-6	;
correctionTable[	1624	] = 	-6	;
correctionTable[	1625	] = 	-6	;
correctionTable[	1626	] = 	-6	;
correctionTable[	1627	] = 	-6	;
correctionTable[	1628	] = 	-6	;
correctionTable[	1629	] = 	-6	;
correctionTable[	1630	] = 	-6	;
correctionTable[	1631	] = 	-6	;
correctionTable[	1632	] = 	-6	;
correctionTable[	1633	] = 	-6	;
correctionTable[	1634	] = 	-6	;
correctionTable[	1635	] = 	-6	;
correctionTable[	1636	] = 	-6	;
correctionTable[	1637	] = 	-6	;
correctionTable[	1638	] = 	-6	;
correctionTable[	1639	] = 	-6	;
correctionTable[	1640	] = 	-6	;
correctionTable[	1641	] = 	-6	;
correctionTable[	1642	] = 	-6	;
correctionTable[	1643	] = 	-6	;
correctionTable[	1644	] = 	-6	;
correctionTable[	1645	] = 	-6	;
correctionTable[	1646	] = 	-6	;
correctionTable[	1647	] = 	-6	;
correctionTable[	1648	] = 	-6	;
correctionTable[	1649	] = 	-6	;
correctionTable[	1650	] = 	-6	;
correctionTable[	1651	] = 	-6	;
correctionTable[	1652	] = 	-6	;
correctionTable[	1653	] = 	-6	;
correctionTable[	1654	] = 	-6	;
correctionTable[	1655	] = 	-6	;
correctionTable[	1656	] = 	-6	;
correctionTable[	1657	] = 	-6	;
correctionTable[	1658	] = 	-6	;
correctionTable[	1659	] = 	-6	;
correctionTable[	1660	] = 	-6	;
correctionTable[	1661	] = 	-6	;
correctionTable[	1662	] = 	-6	;
correctionTable[	1663	] = 	-6	;
correctionTable[	1664	] = 	-6	;
correctionTable[	1665	] = 	-6	;
correctionTable[	1666	] = 	-6	;
correctionTable[	1667	] = 	-7	;
correctionTable[	1668	] = 	-7	;
correctionTable[	1669	] = 	-7	;
correctionTable[	1670	] = 	-7	;
correctionTable[	1671	] = 	-7	;
correctionTable[	1672	] = 	-7	;
correctionTable[	1673	] = 	-7	;
correctionTable[	1674	] = 	-7	;
correctionTable[	1675	] = 	-7	;
correctionTable[	1676	] = 	-7	;
correctionTable[	1677	] = 	-7	;
correctionTable[	1678	] = 	-7	;
correctionTable[	1679	] = 	-7	;
correctionTable[	1680	] = 	-7	;
correctionTable[	1681	] = 	-7	;
correctionTable[	1682	] = 	-7	;
correctionTable[	1683	] = 	-7	;
correctionTable[	1684	] = 	-7	;
correctionTable[	1685	] = 	-7	;
correctionTable[	1686	] = 	-7	;
correctionTable[	1687	] = 	-7	;
correctionTable[	1688	] = 	-7	;
correctionTable[	1689	] = 	-7	;
correctionTable[	1690	] = 	-7	;
correctionTable[	1691	] = 	-7	;
correctionTable[	1692	] = 	-7	;
correctionTable[	1693	] = 	-7	;
correctionTable[	1694	] = 	-7	;
correctionTable[	1695	] = 	-7	;
correctionTable[	1696	] = 	-7	;
correctionTable[	1697	] = 	-7	;
correctionTable[	1698	] = 	-7	;
correctionTable[	1699	] = 	-7	;
correctionTable[	1700	] = 	-7	;
correctionTable[	1701	] = 	-7	;
correctionTable[	1702	] = 	-7	;
correctionTable[	1703	] = 	-7	;
correctionTable[	1704	] = 	-7	;
correctionTable[	1705	] = 	-7	;
correctionTable[	1706	] = 	-7	;
correctionTable[	1707	] = 	-7	;
correctionTable[	1708	] = 	-7	;
correctionTable[	1709	] = 	-7	;
correctionTable[	1710	] = 	-7	;
correctionTable[	1711	] = 	-7	;
correctionTable[	1712	] = 	-7	;
correctionTable[	1713	] = 	-7	;
correctionTable[	1714	] = 	-7	;
correctionTable[	1715	] = 	-7	;
correctionTable[	1716	] = 	-7	;
correctionTable[	1717	] = 	-7	;
correctionTable[	1718	] = 	-7	;
correctionTable[	1719	] = 	-7	;
correctionTable[	1720	] = 	-7	;
correctionTable[	1721	] = 	-7	;
correctionTable[	1722	] = 	-7	;
correctionTable[	1723	] = 	-7	;
correctionTable[	1724	] = 	-7	;
correctionTable[	1725	] = 	-7	;
correctionTable[	1726	] = 	-7	;
correctionTable[	1727	] = 	-7	;
correctionTable[	1728	] = 	-7	;
correctionTable[	1729	] = 	-7	;
correctionTable[	1730	] = 	-7	;
correctionTable[	1731	] = 	-7	;
correctionTable[	1732	] = 	-7	;
correctionTable[	1733	] = 	-7	;
correctionTable[	1734	] = 	-7	;
correctionTable[	1735	] = 	-7	;
correctionTable[	1736	] = 	-7	;
correctionTable[	1737	] = 	-7	;
correctionTable[	1738	] = 	-7	;
correctionTable[	1739	] = 	-7	;
correctionTable[	1740	] = 	-7	;
correctionTable[	1741	] = 	-7	;
correctionTable[	1742	] = 	-7	;
correctionTable[	1743	] = 	-7	;
correctionTable[	1744	] = 	-7	;
correctionTable[	1745	] = 	-7	;
correctionTable[	1746	] = 	-7	;
correctionTable[	1747	] = 	-7	;
correctionTable[	1748	] = 	-7	;
correctionTable[	1749	] = 	-7	;
correctionTable[	1750	] = 	-7	;
correctionTable[	1751	] = 	-7	;
correctionTable[	1752	] = 	-7	;
correctionTable[	1753	] = 	-7	;
correctionTable[	1754	] = 	-7	;
correctionTable[	1755	] = 	-7	;
correctionTable[	1756	] = 	-7	;
correctionTable[	1757	] = 	-7	;
correctionTable[	1758	] = 	-7	;
correctionTable[	1759	] = 	-7	;
correctionTable[	1760	] = 	-7	;
correctionTable[	1761	] = 	-7	;
correctionTable[	1762	] = 	-7	;
correctionTable[	1763	] = 	-7	;
correctionTable[	1764	] = 	-7	;
correctionTable[	1765	] = 	-7	;
correctionTable[	1766	] = 	-7	;
correctionTable[	1767	] = 	-7	;
correctionTable[	1768	] = 	-7	;
correctionTable[	1769	] = 	-7	;
correctionTable[	1770	] = 	-7	;
correctionTable[	1771	] = 	-7	;
correctionTable[	1772	] = 	-7	;
correctionTable[	1773	] = 	-7	;
correctionTable[	1774	] = 	-7	;
correctionTable[	1775	] = 	-7	;
correctionTable[	1776	] = 	-7	;
correctionTable[	1777	] = 	-7	;
correctionTable[	1778	] = 	-7	;
correctionTable[	1779	] = 	-7	;
correctionTable[	1780	] = 	-7	;
correctionTable[	1781	] = 	-7	;
correctionTable[	1782	] = 	-7	;
correctionTable[	1783	] = 	-7	;
correctionTable[	1784	] = 	-7	;
correctionTable[	1785	] = 	-7	;
correctionTable[	1786	] = 	-7	;
correctionTable[	1787	] = 	-7	;
correctionTable[	1788	] = 	-7	;
correctionTable[	1789	] = 	-7	;
correctionTable[	1790	] = 	-7	;
correctionTable[	1791	] = 	-7	;
correctionTable[	1792	] = 	-7	;
correctionTable[	1793	] = 	-7	;
correctionTable[	1794	] = 	-7	;
correctionTable[	1795	] = 	-7	;
correctionTable[	1796	] = 	-7	;
correctionTable[	1797	] = 	-7	;
correctionTable[	1798	] = 	-7	;
correctionTable[	1799	] = 	-7	;
correctionTable[	1800	] = 	-7	;
correctionTable[	1801	] = 	-7	;
correctionTable[	1802	] = 	-7	;
correctionTable[	1803	] = 	-7	;
correctionTable[	1804	] = 	-7	;
correctionTable[	1805	] = 	-7	;
correctionTable[	1806	] = 	-7	;
correctionTable[	1807	] = 	-7	;
correctionTable[	1808	] = 	-7	;
correctionTable[	1809	] = 	-7	;
correctionTable[	1810	] = 	-7	;
correctionTable[	1811	] = 	-7	;
correctionTable[	1812	] = 	-7	;
correctionTable[	1813	] = 	-7	;
correctionTable[	1814	] = 	-7	;
correctionTable[	1815	] = 	-7	;
correctionTable[	1816	] = 	-7	;
correctionTable[	1817	] = 	-8	;
correctionTable[	1818	] = 	-8	;
correctionTable[	1819	] = 	-8	;
correctionTable[	1820	] = 	-8	;
correctionTable[	1821	] = 	-8	;
correctionTable[	1822	] = 	-8	;
correctionTable[	1823	] = 	-8	;
correctionTable[	1824	] = 	-8	;
correctionTable[	1825	] = 	-8	;
correctionTable[	1826	] = 	-8	;
correctionTable[	1827	] = 	-8	;
correctionTable[	1828	] = 	-8	;
correctionTable[	1829	] = 	-8	;
correctionTable[	1830	] = 	-8	;
correctionTable[	1831	] = 	-8	;
correctionTable[	1832	] = 	-8	;
correctionTable[	1833	] = 	-8	;
correctionTable[	1834	] = 	-8	;
correctionTable[	1835	] = 	-8	;
correctionTable[	1836	] = 	-8	;
correctionTable[	1837	] = 	-8	;
correctionTable[	1838	] = 	-8	;
correctionTable[	1839	] = 	-8	;
correctionTable[	1840	] = 	-8	;
correctionTable[	1841	] = 	-8	;
correctionTable[	1842	] = 	-8	;
correctionTable[	1843	] = 	-8	;
correctionTable[	1844	] = 	-8	;
correctionTable[	1845	] = 	-8	;
correctionTable[	1846	] = 	-8	;
correctionTable[	1847	] = 	-8	;
correctionTable[	1848	] = 	-8	;
correctionTable[	1849	] = 	-8	;
correctionTable[	1850	] = 	-8	;
correctionTable[	1851	] = 	-8	;
correctionTable[	1852	] = 	-8	;
correctionTable[	1853	] = 	-8	;
correctionTable[	1854	] = 	-8	;
correctionTable[	1855	] = 	-8	;
correctionTable[	1856	] = 	-8	;
correctionTable[	1857	] = 	-8	;
correctionTable[	1858	] = 	-8	;
correctionTable[	1859	] = 	-8	;
correctionTable[	1860	] = 	-8	;
correctionTable[	1861	] = 	-8	;
correctionTable[	1862	] = 	-8	;
correctionTable[	1863	] = 	-8	;
correctionTable[	1864	] = 	-8	;
correctionTable[	1865	] = 	-8	;
correctionTable[	1866	] = 	-8	;
correctionTable[	1867	] = 	-8	;
correctionTable[	1868	] = 	-8	;
correctionTable[	1869	] = 	-8	;
correctionTable[	1870	] = 	-8	;
correctionTable[	1871	] = 	-8	;
correctionTable[	1872	] = 	-8	;
correctionTable[	1873	] = 	-8	;
correctionTable[	1874	] = 	-8	;
correctionTable[	1875	] = 	-8	;
correctionTable[	1876	] = 	-8	;
correctionTable[	1877	] = 	-8	;
correctionTable[	1878	] = 	-8	;
correctionTable[	1879	] = 	-8	;
correctionTable[	1880	] = 	-8	;
correctionTable[	1881	] = 	-8	;
correctionTable[	1882	] = 	-8	;
correctionTable[	1883	] = 	-8	;
correctionTable[	1884	] = 	-8	;
correctionTable[	1885	] = 	-8	;
correctionTable[	1886	] = 	-8	;
correctionTable[	1887	] = 	-8	;
correctionTable[	1888	] = 	-8	;
correctionTable[	1889	] = 	-8	;
correctionTable[	1890	] = 	-8	;
correctionTable[	1891	] = 	-8	;
correctionTable[	1892	] = 	-8	;
correctionTable[	1893	] = 	-8	;
correctionTable[	1894	] = 	-8	;
correctionTable[	1895	] = 	-8	;
correctionTable[	1896	] = 	-8	;
correctionTable[	1897	] = 	-8	;
correctionTable[	1898	] = 	-8	;
correctionTable[	1899	] = 	-8	;
correctionTable[	1900	] = 	-8	;
correctionTable[	1901	] = 	-8	;
correctionTable[	1902	] = 	-8	;
correctionTable[	1903	] = 	-8	;
correctionTable[	1904	] = 	-8	;
correctionTable[	1905	] = 	-8	;
correctionTable[	1906	] = 	-8	;
correctionTable[	1907	] = 	-8	;
correctionTable[	1908	] = 	-8	;
correctionTable[	1909	] = 	-8	;
correctionTable[	1910	] = 	-8	;
correctionTable[	1911	] = 	-8	;
correctionTable[	1912	] = 	-8	;
correctionTable[	1913	] = 	-8	;
correctionTable[	1914	] = 	-8	;
correctionTable[	1915	] = 	-8	;
correctionTable[	1916	] = 	-8	;
correctionTable[	1917	] = 	-8	;
correctionTable[	1918	] = 	-8	;
correctionTable[	1919	] = 	-8	;
correctionTable[	1920	] = 	-8	;
correctionTable[	1921	] = 	-8	;
correctionTable[	1922	] = 	-8	;
correctionTable[	1923	] = 	-8	;
correctionTable[	1924	] = 	-8	;
correctionTable[	1925	] = 	-8	;
correctionTable[	1926	] = 	-8	;
correctionTable[	1927	] = 	-8	;
correctionTable[	1928	] = 	-8	;
correctionTable[	1929	] = 	-8	;
correctionTable[	1930	] = 	-8	;
correctionTable[	1931	] = 	-8	;
correctionTable[	1932	] = 	-8	;
correctionTable[	1933	] = 	-8	;
correctionTable[	1934	] = 	-8	;
correctionTable[	1935	] = 	-8	;
correctionTable[	1936	] = 	-8	;
correctionTable[	1937	] = 	-8	;
correctionTable[	1938	] = 	-8	;
correctionTable[	1939	] = 	-8	;
correctionTable[	1940	] = 	-8	;
correctionTable[	1941	] = 	-8	;
correctionTable[	1942	] = 	-8	;
correctionTable[	1943	] = 	-8	;
correctionTable[	1944	] = 	-9	;
correctionTable[	1945	] = 	-9	;
correctionTable[	1946	] = 	-9	;
correctionTable[	1947	] = 	-9	;
correctionTable[	1948	] = 	-9	;
correctionTable[	1949	] = 	-9	;
correctionTable[	1950	] = 	-9	;
correctionTable[	1951	] = 	-9	;
correctionTable[	1952	] = 	-9	;
correctionTable[	1953	] = 	-9	;
correctionTable[	1954	] = 	-9	;
correctionTable[	1955	] = 	-9	;
correctionTable[	1956	] = 	-9	;
correctionTable[	1957	] = 	-9	;
correctionTable[	1958	] = 	-9	;
correctionTable[	1959	] = 	-9	;
correctionTable[	1960	] = 	-9	;
correctionTable[	1961	] = 	-9	;
correctionTable[	1962	] = 	-9	;
correctionTable[	1963	] = 	-9	;
correctionTable[	1964	] = 	-9	;
correctionTable[	1965	] = 	-9	;
correctionTable[	1966	] = 	-9	;
correctionTable[	1967	] = 	-9	;
correctionTable[	1968	] = 	-9	;
correctionTable[	1969	] = 	-9	;
correctionTable[	1970	] = 	-9	;
correctionTable[	1971	] = 	-9	;
correctionTable[	1972	] = 	-9	;
correctionTable[	1973	] = 	-9	;
correctionTable[	1974	] = 	-9	;
correctionTable[	1975	] = 	-9	;
correctionTable[	1976	] = 	-9	;
correctionTable[	1977	] = 	-9	;
correctionTable[	1978	] = 	-9	;
correctionTable[	1979	] = 	-9	;
correctionTable[	1980	] = 	-9	;
correctionTable[	1981	] = 	-9	;
correctionTable[	1982	] = 	-9	;
correctionTable[	1983	] = 	-9	;
correctionTable[	1984	] = 	-9	;
correctionTable[	1985	] = 	-9	;
correctionTable[	1986	] = 	-9	;
correctionTable[	1987	] = 	-9	;
correctionTable[	1988	] = 	-9	;
correctionTable[	1989	] = 	-9	;
correctionTable[	1990	] = 	-9	;
correctionTable[	1991	] = 	-9	;
correctionTable[	1992	] = 	-9	;
correctionTable[	1993	] = 	-9	;
correctionTable[	1994	] = 	-9	;
correctionTable[	1995	] = 	-9	;
correctionTable[	1996	] = 	-9	;
correctionTable[	1997	] = 	-9	;
correctionTable[	1998	] = 	-9	;
correctionTable[	1999	] = 	-9	;
correctionTable[	2000	] = 	-9	;
correctionTable[	2001	] = 	-9	;
correctionTable[	2002	] = 	-9	;
correctionTable[	2003	] = 	-9	;
correctionTable[	2004	] = 	-9	;
correctionTable[	2005	] = 	-9	;
correctionTable[	2006	] = 	-9	;
correctionTable[	2007	] = 	-9	;
correctionTable[	2008	] = 	-9	;
correctionTable[	2009	] = 	-9	;
correctionTable[	2010	] = 	-9	;
correctionTable[	2011	] = 	-9	;
correctionTable[	2012	] = 	-9	;
correctionTable[	2013	] = 	-9	;
correctionTable[	2014	] = 	-9	;
correctionTable[	2015	] = 	-9	;
correctionTable[	2016	] = 	-9	;
correctionTable[	2017	] = 	-9	;
correctionTable[	2018	] = 	-9	;
correctionTable[	2019	] = 	-9	;
correctionTable[	2020	] = 	-9	;
correctionTable[	2021	] = 	-9	;
correctionTable[	2022	] = 	-9	;
correctionTable[	2023	] = 	-9	;
correctionTable[	2024	] = 	-9	;
correctionTable[	2025	] = 	-9	;
correctionTable[	2026	] = 	-9	;
correctionTable[	2027	] = 	-9	;
correctionTable[	2028	] = 	-9	;
correctionTable[	2029	] = 	-9	;
correctionTable[	2030	] = 	-9	;
correctionTable[	2031	] = 	-9	;
correctionTable[	2032	] = 	-9	;
correctionTable[	2033	] = 	-9	;
correctionTable[	2034	] = 	-9	;
correctionTable[	2035	] = 	-9	;
correctionTable[	2036	] = 	-9	;
correctionTable[	2037	] = 	-9	;
correctionTable[	2038	] = 	-9	;
correctionTable[	2039	] = 	-9	;
correctionTable[	2040	] = 	-9	;
correctionTable[	2041	] = 	-9	;
correctionTable[	2042	] = 	-9	;
correctionTable[	2043	] = 	-9	;
correctionTable[	2044	] = 	-9	;
correctionTable[	2045	] = 	-9	;
correctionTable[	2046	] = 	-9	;
correctionTable[	2047	] = 	-9	;
correctionTable[	2048	] = 	-9	;
correctionTable[	2049	] = 	-9	;
correctionTable[	2050	] = 	-9	;
correctionTable[	2051	] = 	-9	;
correctionTable[	2052	] = 	-9	;
correctionTable[	2053	] = 	-9	;
correctionTable[	2054	] = 	-9	;
correctionTable[	2055	] = 	-9	;
correctionTable[	2056	] = 	-9	;
correctionTable[	2057	] = 	-9	;
correctionTable[	2058	] = 	-9	;
correctionTable[	2059	] = 	-10	;
correctionTable[	2060	] = 	-10	;
correctionTable[	2061	] = 	-10	;
correctionTable[	2062	] = 	-10	;
correctionTable[	2063	] = 	-10	;
correctionTable[	2064	] = 	-10	;
correctionTable[	2065	] = 	-10	;
correctionTable[	2066	] = 	-10	;
correctionTable[	2067	] = 	-10	;
correctionTable[	2068	] = 	-10	;
correctionTable[	2069	] = 	-10	;
correctionTable[	2070	] = 	-10	;
correctionTable[	2071	] = 	-10	;
correctionTable[	2072	] = 	-10	;
correctionTable[	2073	] = 	-10	;
correctionTable[	2074	] = 	-10	;
correctionTable[	2075	] = 	-10	;
correctionTable[	2076	] = 	-10	;
correctionTable[	2077	] = 	-10	;
correctionTable[	2078	] = 	-10	;
correctionTable[	2079	] = 	-10	;
correctionTable[	2080	] = 	-10	;
correctionTable[	2081	] = 	-10	;
correctionTable[	2082	] = 	-10	;
correctionTable[	2083	] = 	-10	;
correctionTable[	2084	] = 	-10	;
correctionTable[	2085	] = 	-10	;
correctionTable[	2086	] = 	-10	;
correctionTable[	2087	] = 	-10	;
correctionTable[	2088	] = 	-10	;
correctionTable[	2089	] = 	-10	;
correctionTable[	2090	] = 	-10	;
correctionTable[	2091	] = 	-10	;
correctionTable[	2092	] = 	-10	;
correctionTable[	2093	] = 	-10	;
correctionTable[	2094	] = 	-10	;
correctionTable[	2095	] = 	-10	;
correctionTable[	2096	] = 	-10	;
correctionTable[	2097	] = 	-10	;
correctionTable[	2098	] = 	-10	;
correctionTable[	2099	] = 	-10	;
correctionTable[	2100	] = 	-10	;
correctionTable[	2101	] = 	-10	;
correctionTable[	2102	] = 	-10	;
correctionTable[	2103	] = 	-10	;
correctionTable[	2104	] = 	-10	;
correctionTable[	2105	] = 	-10	;
correctionTable[	2106	] = 	-10	;
correctionTable[	2107	] = 	-10	;
correctionTable[	2108	] = 	-10	;
correctionTable[	2109	] = 	-10	;
correctionTable[	2110	] = 	-10	;
correctionTable[	2111	] = 	-10	;
correctionTable[	2112	] = 	-10	;
correctionTable[	2113	] = 	-10	;
correctionTable[	2114	] = 	-10	;
correctionTable[	2115	] = 	-10	;
correctionTable[	2116	] = 	-10	;
correctionTable[	2117	] = 	-10	;
correctionTable[	2118	] = 	-10	;
correctionTable[	2119	] = 	-10	;
correctionTable[	2120	] = 	-10	;
correctionTable[	2121	] = 	-10	;
correctionTable[	2122	] = 	-10	;
correctionTable[	2123	] = 	-10	;
correctionTable[	2124	] = 	-10	;
correctionTable[	2125	] = 	-10	;
correctionTable[	2126	] = 	-10	;
correctionTable[	2127	] = 	-10	;
correctionTable[	2128	] = 	-10	;
correctionTable[	2129	] = 	-10	;
correctionTable[	2130	] = 	-10	;
correctionTable[	2131	] = 	-10	;
correctionTable[	2132	] = 	-10	;
correctionTable[	2133	] = 	-10	;
correctionTable[	2134	] = 	-10	;
correctionTable[	2135	] = 	-10	;
correctionTable[	2136	] = 	-10	;
correctionTable[	2137	] = 	-10	;
correctionTable[	2138	] = 	-10	;
correctionTable[	2139	] = 	-10	;
correctionTable[	2140	] = 	-10	;
correctionTable[	2141	] = 	-10	;
correctionTable[	2142	] = 	-10	;
correctionTable[	2143	] = 	-10	;
correctionTable[	2144	] = 	-10	;
correctionTable[	2145	] = 	-10	;
correctionTable[	2146	] = 	-10	;
correctionTable[	2147	] = 	-10	;
correctionTable[	2148	] = 	-10	;
correctionTable[	2149	] = 	-10	;
correctionTable[	2150	] = 	-10	;
correctionTable[	2151	] = 	-10	;
correctionTable[	2152	] = 	-10	;
correctionTable[	2153	] = 	-10	;
correctionTable[	2154	] = 	-10	;
correctionTable[	2155	] = 	-10	;
correctionTable[	2156	] = 	-10	;
correctionTable[	2157	] = 	-10	;
correctionTable[	2158	] = 	-10	;
correctionTable[	2159	] = 	-10	;
correctionTable[	2160	] = 	-10	;
correctionTable[	2161	] = 	-10	;
correctionTable[	2162	] = 	-10	;
correctionTable[	2163	] = 	-10	;
correctionTable[	2164	] = 	-10	;
correctionTable[	2165	] = 	-10	;
correctionTable[	2166	] = 	-10	;
correctionTable[	2167	] = 	-10	;
correctionTable[	2168	] = 	-10	;
correctionTable[	2169	] = 	-11	;
correctionTable[	2170	] = 	-11	;
correctionTable[	2171	] = 	-11	;
correctionTable[	2172	] = 	-11	;
correctionTable[	2173	] = 	-11	;
correctionTable[	2174	] = 	-11	;
correctionTable[	2175	] = 	-11	;
correctionTable[	2176	] = 	-11	;
correctionTable[	2177	] = 	-11	;
correctionTable[	2178	] = 	-11	;
correctionTable[	2179	] = 	-11	;
correctionTable[	2180	] = 	-11	;
correctionTable[	2181	] = 	-11	;
correctionTable[	2182	] = 	-11	;
correctionTable[	2183	] = 	-11	;
correctionTable[	2184	] = 	-11	;
correctionTable[	2185	] = 	-11	;
correctionTable[	2186	] = 	-11	;
correctionTable[	2187	] = 	-11	;
correctionTable[	2188	] = 	-11	;
correctionTable[	2189	] = 	-11	;
correctionTable[	2190	] = 	-11	;
correctionTable[	2191	] = 	-11	;
correctionTable[	2192	] = 	-11	;
correctionTable[	2193	] = 	-11	;
correctionTable[	2194	] = 	-11	;
correctionTable[	2195	] = 	-11	;
correctionTable[	2196	] = 	-11	;
correctionTable[	2197	] = 	-11	;
correctionTable[	2198	] = 	-11	;
correctionTable[	2199	] = 	-11	;
correctionTable[	2200	] = 	-11	;
correctionTable[	2201	] = 	-11	;
correctionTable[	2202	] = 	-11	;
correctionTable[	2203	] = 	-11	;
correctionTable[	2204	] = 	-11	;
correctionTable[	2205	] = 	-11	;
correctionTable[	2206	] = 	-11	;
correctionTable[	2207	] = 	-11	;
correctionTable[	2208	] = 	-11	;
correctionTable[	2209	] = 	-11	;
correctionTable[	2210	] = 	-11	;
correctionTable[	2211	] = 	-11	;
correctionTable[	2212	] = 	-11	;
correctionTable[	2213	] = 	-11	;
correctionTable[	2214	] = 	-11	;
correctionTable[	2215	] = 	-11	;
correctionTable[	2216	] = 	-11	;
correctionTable[	2217	] = 	-11	;
correctionTable[	2218	] = 	-11	;
correctionTable[	2219	] = 	-11	;
correctionTable[	2220	] = 	-11	;
correctionTable[	2221	] = 	-11	;
correctionTable[	2222	] = 	-11	;
correctionTable[	2223	] = 	-11	;
correctionTable[	2224	] = 	-11	;
correctionTable[	2225	] = 	-11	;
correctionTable[	2226	] = 	-11	;
correctionTable[	2227	] = 	-11	;
correctionTable[	2228	] = 	-11	;
correctionTable[	2229	] = 	-11	;
correctionTable[	2230	] = 	-11	;
correctionTable[	2231	] = 	-11	;
correctionTable[	2232	] = 	-11	;
correctionTable[	2233	] = 	-11	;
correctionTable[	2234	] = 	-11	;
correctionTable[	2235	] = 	-11	;
correctionTable[	2236	] = 	-11	;
correctionTable[	2237	] = 	-11	;
correctionTable[	2238	] = 	-11	;
correctionTable[	2239	] = 	-11	;
correctionTable[	2240	] = 	-11	;
correctionTable[	2241	] = 	-11	;
correctionTable[	2242	] = 	-11	;
correctionTable[	2243	] = 	-11	;
correctionTable[	2244	] = 	-11	;
correctionTable[	2245	] = 	-11	;
correctionTable[	2246	] = 	-11	;
correctionTable[	2247	] = 	-11	;
correctionTable[	2248	] = 	-11	;
correctionTable[	2249	] = 	-11	;
correctionTable[	2250	] = 	-11	;
correctionTable[	2251	] = 	-11	;
correctionTable[	2252	] = 	-11	;
correctionTable[	2253	] = 	-11	;
correctionTable[	2254	] = 	-11	;
correctionTable[	2255	] = 	-11	;
correctionTable[	2256	] = 	-11	;
correctionTable[	2257	] = 	-11	;
correctionTable[	2258	] = 	-11	;
correctionTable[	2259	] = 	-11	;
correctionTable[	2260	] = 	-11	;
correctionTable[	2261	] = 	-11	;
correctionTable[	2262	] = 	-11	;
correctionTable[	2263	] = 	-11	;
correctionTable[	2264	] = 	-11	;
correctionTable[	2265	] = 	-11	;
correctionTable[	2266	] = 	-11	;
correctionTable[	2267	] = 	-11	;
correctionTable[	2268	] = 	-11	;
correctionTable[	2269	] = 	-11	;
correctionTable[	2270	] = 	-11	;
correctionTable[	2271	] = 	-11	;
correctionTable[	2272	] = 	-11	;
correctionTable[	2273	] = 	-11	;
correctionTable[	2274	] = 	-11	;
correctionTable[	2275	] = 	-11	;
correctionTable[	2276	] = 	-11	;
correctionTable[	2277	] = 	-11	;
correctionTable[	2278	] = 	-11	;
correctionTable[	2279	] = 	-11	;
correctionTable[	2280	] = 	-11	;
correctionTable[	2281	] = 	-11	;
correctionTable[	2282	] = 	-11	;
correctionTable[	2283	] = 	-11	;
correctionTable[	2284	] = 	-11	;
correctionTable[	2285	] = 	-11	;
correctionTable[	2286	] = 	-12	;
correctionTable[	2287	] = 	-12	;
correctionTable[	2288	] = 	-12	;
correctionTable[	2289	] = 	-12	;
correctionTable[	2290	] = 	-12	;
correctionTable[	2291	] = 	-12	;
correctionTable[	2292	] = 	-12	;
correctionTable[	2293	] = 	-12	;
correctionTable[	2294	] = 	-12	;
correctionTable[	2295	] = 	-12	;
correctionTable[	2296	] = 	-12	;
correctionTable[	2297	] = 	-12	;
correctionTable[	2298	] = 	-12	;
correctionTable[	2299	] = 	-12	;
correctionTable[	2300	] = 	-12	;
correctionTable[	2301	] = 	-12	;
correctionTable[	2302	] = 	-12	;
correctionTable[	2303	] = 	-12	;
correctionTable[	2304	] = 	-12	;
correctionTable[	2305	] = 	-12	;
correctionTable[	2306	] = 	-12	;
correctionTable[	2307	] = 	-12	;
correctionTable[	2308	] = 	-12	;
correctionTable[	2309	] = 	-12	;
correctionTable[	2310	] = 	-12	;
correctionTable[	2311	] = 	-12	;
correctionTable[	2312	] = 	-12	;
correctionTable[	2313	] = 	-12	;
correctionTable[	2314	] = 	-12	;
correctionTable[	2315	] = 	-12	;
correctionTable[	2316	] = 	-12	;
correctionTable[	2317	] = 	-12	;
correctionTable[	2318	] = 	-12	;
correctionTable[	2319	] = 	-12	;
correctionTable[	2320	] = 	-12	;
correctionTable[	2321	] = 	-12	;
correctionTable[	2322	] = 	-12	;
correctionTable[	2323	] = 	-12	;
correctionTable[	2324	] = 	-12	;
correctionTable[	2325	] = 	-12	;
correctionTable[	2326	] = 	-12	;
correctionTable[	2327	] = 	-12	;
correctionTable[	2328	] = 	-12	;
correctionTable[	2329	] = 	-12	;
correctionTable[	2330	] = 	-12	;
correctionTable[	2331	] = 	-12	;
correctionTable[	2332	] = 	-12	;
correctionTable[	2333	] = 	-12	;
correctionTable[	2334	] = 	-12	;
correctionTable[	2335	] = 	-12	;
correctionTable[	2336	] = 	-12	;
correctionTable[	2337	] = 	-12	;
correctionTable[	2338	] = 	-12	;
correctionTable[	2339	] = 	-12	;
correctionTable[	2340	] = 	-12	;
correctionTable[	2341	] = 	-12	;
correctionTable[	2342	] = 	-12	;
correctionTable[	2343	] = 	-12	;
correctionTable[	2344	] = 	-12	;
correctionTable[	2345	] = 	-12	;
correctionTable[	2346	] = 	-12	;
correctionTable[	2347	] = 	-12	;
correctionTable[	2348	] = 	-12	;
correctionTable[	2349	] = 	-12	;
correctionTable[	2350	] = 	-12	;
correctionTable[	2351	] = 	-12	;
correctionTable[	2352	] = 	-12	;
correctionTable[	2353	] = 	-12	;
correctionTable[	2354	] = 	-12	;
correctionTable[	2355	] = 	-12	;
correctionTable[	2356	] = 	-12	;
correctionTable[	2357	] = 	-12	;
correctionTable[	2358	] = 	-12	;
correctionTable[	2359	] = 	-12	;
correctionTable[	2360	] = 	-12	;
correctionTable[	2361	] = 	-12	;
correctionTable[	2362	] = 	-12	;
correctionTable[	2363	] = 	-12	;
correctionTable[	2364	] = 	-12	;
correctionTable[	2365	] = 	-12	;
correctionTable[	2366	] = 	-12	;
correctionTable[	2367	] = 	-12	;
correctionTable[	2368	] = 	-12	;
correctionTable[	2369	] = 	-12	;
correctionTable[	2370	] = 	-12	;
correctionTable[	2371	] = 	-12	;
correctionTable[	2372	] = 	-12	;
correctionTable[	2373	] = 	-12	;
correctionTable[	2374	] = 	-12	;
correctionTable[	2375	] = 	-12	;
correctionTable[	2376	] = 	-12	;
correctionTable[	2377	] = 	-12	;
correctionTable[	2378	] = 	-12	;
correctionTable[	2379	] = 	-12	;
correctionTable[	2380	] = 	-12	;
correctionTable[	2381	] = 	-12	;
correctionTable[	2382	] = 	-12	;
correctionTable[	2383	] = 	-12	;
correctionTable[	2384	] = 	-12	;
correctionTable[	2385	] = 	-12	;
correctionTable[	2386	] = 	-12	;
correctionTable[	2387	] = 	-12	;
correctionTable[	2388	] = 	-12	;
correctionTable[	2389	] = 	-12	;
correctionTable[	2390	] = 	-12	;
correctionTable[	2391	] = 	-12	;
correctionTable[	2392	] = 	-12	;
correctionTable[	2393	] = 	-12	;
correctionTable[	2394	] = 	-12	;
correctionTable[	2395	] = 	-12	;
correctionTable[	2396	] = 	-12	;
correctionTable[	2397	] = 	-12	;
correctionTable[	2398	] = 	-12	;
correctionTable[	2399	] = 	-12	;
correctionTable[	2400	] = 	-12	;
correctionTable[	2401	] = 	-12	;
correctionTable[	2402	] = 	-12	;
correctionTable[	2403	] = 	-12	;
correctionTable[	2404	] = 	-12	;
correctionTable[	2405	] = 	-12	;
correctionTable[	2406	] = 	-12	;
correctionTable[	2407	] = 	-12	;
correctionTable[	2408	] = 	-12	;
correctionTable[	2409	] = 	-12	;
correctionTable[	2410	] = 	-12	;
correctionTable[	2411	] = 	-12	;
correctionTable[	2412	] = 	-12	;
correctionTable[	2413	] = 	-12	;
correctionTable[	2414	] = 	-12	;
correctionTable[	2415	] = 	-12	;
correctionTable[	2416	] = 	-12	;
correctionTable[	2417	] = 	-12	;
correctionTable[	2418	] = 	-12	;
correctionTable[	2419	] = 	-12	;
correctionTable[	2420	] = 	-12	;
correctionTable[	2421	] = 	-12	;
correctionTable[	2422	] = 	-12	;
correctionTable[	2423	] = 	-12	;
correctionTable[	2424	] = 	-12	;
correctionTable[	2425	] = 	-12	;
correctionTable[	2426	] = 	-12	;
correctionTable[	2427	] = 	-12	;
correctionTable[	2428	] = 	-12	;
correctionTable[	2429	] = 	-12	;
correctionTable[	2430	] = 	-12	;
correctionTable[	2431	] = 	-13	;
correctionTable[	2432	] = 	-13	;
correctionTable[	2433	] = 	-13	;
correctionTable[	2434	] = 	-13	;
correctionTable[	2435	] = 	-13	;
correctionTable[	2436	] = 	-13	;
correctionTable[	2437	] = 	-13	;
correctionTable[	2438	] = 	-13	;
correctionTable[	2439	] = 	-13	;
correctionTable[	2440	] = 	-13	;
correctionTable[	2441	] = 	-13	;
correctionTable[	2442	] = 	-13	;
correctionTable[	2443	] = 	-13	;
correctionTable[	2444	] = 	-13	;
correctionTable[	2445	] = 	-13	;
correctionTable[	2446	] = 	-13	;
correctionTable[	2447	] = 	-13	;
correctionTable[	2448	] = 	-13	;
correctionTable[	2449	] = 	-13	;
correctionTable[	2450	] = 	-13	;
correctionTable[	2451	] = 	-13	;
correctionTable[	2452	] = 	-13	;
correctionTable[	2453	] = 	-13	;
correctionTable[	2454	] = 	-13	;
correctionTable[	2455	] = 	-13	;
correctionTable[	2456	] = 	-13	;
correctionTable[	2457	] = 	-13	;
correctionTable[	2458	] = 	-13	;
correctionTable[	2459	] = 	-13	;
correctionTable[	2460	] = 	-13	;
correctionTable[	2461	] = 	-13	;
correctionTable[	2462	] = 	-13	;
correctionTable[	2463	] = 	-13	;
correctionTable[	2464	] = 	-13	;
correctionTable[	2465	] = 	-13	;
correctionTable[	2466	] = 	-13	;
correctionTable[	2467	] = 	-13	;
correctionTable[	2468	] = 	-13	;
correctionTable[	2469	] = 	-13	;
correctionTable[	2470	] = 	-13	;
correctionTable[	2471	] = 	-13	;
correctionTable[	2472	] = 	-13	;
correctionTable[	2473	] = 	-13	;
correctionTable[	2474	] = 	-13	;
correctionTable[	2475	] = 	-13	;
correctionTable[	2476	] = 	-13	;
correctionTable[	2477	] = 	-13	;
correctionTable[	2478	] = 	-13	;
correctionTable[	2479	] = 	-13	;
correctionTable[	2480	] = 	-13	;
correctionTable[	2481	] = 	-13	;
correctionTable[	2482	] = 	-13	;
correctionTable[	2483	] = 	-13	;
correctionTable[	2484	] = 	-13	;
correctionTable[	2485	] = 	-13	;
correctionTable[	2486	] = 	-13	;
correctionTable[	2487	] = 	-13	;
correctionTable[	2488	] = 	-13	;
correctionTable[	2489	] = 	-13	;
correctionTable[	2490	] = 	-13	;
correctionTable[	2491	] = 	-13	;
correctionTable[	2492	] = 	-13	;
correctionTable[	2493	] = 	-13	;
correctionTable[	2494	] = 	-13	;
correctionTable[	2495	] = 	-13	;
correctionTable[	2496	] = 	-13	;
correctionTable[	2497	] = 	-13	;
correctionTable[	2498	] = 	-13	;
correctionTable[	2499	] = 	-13	;
correctionTable[	2500	] = 	-13	;
correctionTable[	2501	] = 	-13	;
correctionTable[	2502	] = 	-13	;
correctionTable[	2503	] = 	-13	;
correctionTable[	2504	] = 	-13	;
correctionTable[	2505	] = 	-13	;
correctionTable[	2506	] = 	-13	;
correctionTable[	2507	] = 	-13	;
correctionTable[	2508	] = 	-13	;
correctionTable[	2509	] = 	-13	;
correctionTable[	2510	] = 	-13	;
correctionTable[	2511	] = 	-13	;
correctionTable[	2512	] = 	-13	;
correctionTable[	2513	] = 	-13	;
correctionTable[	2514	] = 	-13	;
correctionTable[	2515	] = 	-13	;
correctionTable[	2516	] = 	-13	;
correctionTable[	2517	] = 	-13	;
correctionTable[	2518	] = 	-13	;
correctionTable[	2519	] = 	-13	;
correctionTable[	2520	] = 	-13	;
correctionTable[	2521	] = 	-13	;
correctionTable[	2522	] = 	-13	;
correctionTable[	2523	] = 	-13	;
correctionTable[	2524	] = 	-13	;
correctionTable[	2525	] = 	-13	;
correctionTable[	2526	] = 	-13	;
correctionTable[	2527	] = 	-13	;
correctionTable[	2528	] = 	-13	;
correctionTable[	2529	] = 	-13	;
correctionTable[	2530	] = 	-13	;
correctionTable[	2531	] = 	-13	;
correctionTable[	2532	] = 	-13	;
correctionTable[	2533	] = 	-13	;
correctionTable[	2534	] = 	-13	;
correctionTable[	2535	] = 	-13	;
correctionTable[	2536	] = 	-13	;
correctionTable[	2537	] = 	-13	;
correctionTable[	2538	] = 	-13	;
correctionTable[	2539	] = 	-13	;
correctionTable[	2540	] = 	-13	;
correctionTable[	2541	] = 	-13	;
correctionTable[	2542	] = 	-13	;
correctionTable[	2543	] = 	-13	;
correctionTable[	2544	] = 	-13	;
correctionTable[	2545	] = 	-13	;
correctionTable[	2546	] = 	-13	;
correctionTable[	2547	] = 	-13	;
correctionTable[	2548	] = 	-13	;
correctionTable[	2549	] = 	-13	;
correctionTable[	2550	] = 	-13	;
correctionTable[	2551	] = 	-13	;
correctionTable[	2552	] = 	-13	;
correctionTable[	2553	] = 	-13	;
correctionTable[	2554	] = 	-13	;
correctionTable[	2555	] = 	-13	;
correctionTable[	2556	] = 	-13	;
correctionTable[	2557	] = 	-13	;
correctionTable[	2558	] = 	-13	;
correctionTable[	2559	] = 	-13	;
correctionTable[	2560	] = 	-13	;
correctionTable[	2561	] = 	-13	;
correctionTable[	2562	] = 	-13	;
correctionTable[	2563	] = 	-13	;
correctionTable[	2564	] = 	-13	;
correctionTable[	2565	] = 	-13	;
correctionTable[	2566	] = 	-13	;
correctionTable[	2567	] = 	-13	;
correctionTable[	2568	] = 	-13	;
correctionTable[	2569	] = 	-13	;
correctionTable[	2570	] = 	-13	;
correctionTable[	2571	] = 	-13	;
correctionTable[	2572	] = 	-13	;
correctionTable[	2573	] = 	-13	;
correctionTable[	2574	] = 	-13	;
correctionTable[	2575	] = 	-13	;
correctionTable[	2576	] = 	-13	;
correctionTable[	2577	] = 	-13	;
correctionTable[	2578	] = 	-13	;
correctionTable[	2579	] = 	-13	;
correctionTable[	2580	] = 	-13	;
correctionTable[	2581	] = 	-13	;
correctionTable[	2582	] = 	-13	;
correctionTable[	2583	] = 	-13	;
correctionTable[	2584	] = 	-13	;
correctionTable[	2585	] = 	-13	;
correctionTable[	2586	] = 	-13	;
correctionTable[	2587	] = 	-13	;
correctionTable[	2588	] = 	-13	;
correctionTable[	2589	] = 	-13	;
correctionTable[	2590	] = 	-13	;
correctionTable[	2591	] = 	-13	;
correctionTable[	2592	] = 	-13	;
correctionTable[	2593	] = 	-13	;
correctionTable[	2594	] = 	-13	;
correctionTable[	2595	] = 	-13	;
correctionTable[	2596	] = 	-13	;
correctionTable[	2597	] = 	-13	;
correctionTable[	2598	] = 	-13	;
correctionTable[	2599	] = 	-13	;
correctionTable[	2600	] = 	-13	;
correctionTable[	2601	] = 	-13	;
correctionTable[	2602	] = 	-13	;
correctionTable[	2603	] = 	-13	;
correctionTable[	2604	] = 	-13	;
correctionTable[	2605	] = 	-13	;
correctionTable[	2606	] = 	-13	;
correctionTable[	2607	] = 	-13	;
correctionTable[	2608	] = 	-13	;
correctionTable[	2609	] = 	-13	;
correctionTable[	2610	] = 	-13	;
correctionTable[	2611	] = 	-13	;
correctionTable[	2612	] = 	-13	;
correctionTable[	2613	] = 	-13	;
correctionTable[	2614	] = 	-13	;
correctionTable[	2615	] = 	-13	;
correctionTable[	2616	] = 	-13	;
correctionTable[	2617	] = 	-13	;
correctionTable[	2618	] = 	-13	;
correctionTable[	2619	] = 	-13	;
correctionTable[	2620	] = 	-13	;
correctionTable[	2621	] = 	-13	;
correctionTable[	2622	] = 	-13	;
correctionTable[	2623	] = 	-13	;
correctionTable[	2624	] = 	-13	;
correctionTable[	2625	] = 	-13	;
correctionTable[	2626	] = 	-13	;
correctionTable[	2627	] = 	-13	;
correctionTable[	2628	] = 	-13	;
correctionTable[	2629	] = 	-13	;
correctionTable[	2630	] = 	-13	;
correctionTable[	2631	] = 	-13	;
correctionTable[	2632	] = 	-13	;
correctionTable[	2633	] = 	-13	;
correctionTable[	2634	] = 	-13	;
correctionTable[	2635	] = 	-13	;
correctionTable[	2636	] = 	-13	;
correctionTable[	2637	] = 	-13	;
correctionTable[	2638	] = 	-13	;
correctionTable[	2639	] = 	-13	;
correctionTable[	2640	] = 	-13	;
correctionTable[	2641	] = 	-13	;
correctionTable[	2642	] = 	-13	;
correctionTable[	2643	] = 	-13	;
correctionTable[	2644	] = 	-13	;
correctionTable[	2645	] = 	-13	;
correctionTable[	2646	] = 	-13	;
correctionTable[	2647	] = 	-13	;
correctionTable[	2648	] = 	-13	;
correctionTable[	2649	] = 	-13	;
correctionTable[	2650	] = 	-13	;
correctionTable[	2651	] = 	-13	;
correctionTable[	2652	] = 	-13	;
correctionTable[	2653	] = 	-13	;
correctionTable[	2654	] = 	-13	;
correctionTable[	2655	] = 	-13	;
correctionTable[	2656	] = 	-13	;
correctionTable[	2657	] = 	-13	;
correctionTable[	2658	] = 	-13	;
correctionTable[	2659	] = 	-13	;
correctionTable[	2660	] = 	-13	;
correctionTable[	2661	] = 	-13	;
correctionTable[	2662	] = 	-13	;
correctionTable[	2663	] = 	-13	;
correctionTable[	2664	] = 	-13	;
correctionTable[	2665	] = 	-13	;
correctionTable[	2666	] = 	-13	;
correctionTable[	2667	] = 	-13	;
correctionTable[	2668	] = 	-13	;
correctionTable[	2669	] = 	-13	;
correctionTable[	2670	] = 	-13	;
correctionTable[	2671	] = 	-13	;
correctionTable[	2672	] = 	-13	;
correctionTable[	2673	] = 	-13	;
correctionTable[	2674	] = 	-13	;
correctionTable[	2675	] = 	-13	;
correctionTable[	2676	] = 	-13	;
correctionTable[	2677	] = 	-13	;
correctionTable[	2678	] = 	-13	;
correctionTable[	2679	] = 	-13	;
correctionTable[	2680	] = 	-13	;
correctionTable[	2681	] = 	-13	;
correctionTable[	2682	] = 	-13	;
correctionTable[	2683	] = 	-13	;
correctionTable[	2684	] = 	-13	;
correctionTable[	2685	] = 	-13	;
correctionTable[	2686	] = 	-13	;
correctionTable[	2687	] = 	-13	;
correctionTable[	2688	] = 	-13	;
correctionTable[	2689	] = 	-13	;
correctionTable[	2690	] = 	-13	;
correctionTable[	2691	] = 	-13	;
correctionTable[	2692	] = 	-13	;
correctionTable[	2693	] = 	-13	;
correctionTable[	2694	] = 	-13	;
correctionTable[	2695	] = 	-13	;
correctionTable[	2696	] = 	-13	;
correctionTable[	2697	] = 	-13	;
correctionTable[	2698	] = 	-13	;
correctionTable[	2699	] = 	-13	;
correctionTable[	2700	] = 	-13	;
correctionTable[	2701	] = 	-13	;
correctionTable[	2702	] = 	-13	;
correctionTable[	2703	] = 	-13	;
correctionTable[	2704	] = 	-13	;
correctionTable[	2705	] = 	-13	;
correctionTable[	2706	] = 	-13	;
correctionTable[	2707	] = 	-13	;
correctionTable[	2708	] = 	-13	;
correctionTable[	2709	] = 	-13	;
correctionTable[	2710	] = 	-13	;
correctionTable[	2711	] = 	-13	;
correctionTable[	2712	] = 	-13	;
correctionTable[	2713	] = 	-13	;
correctionTable[	2714	] = 	-13	;
correctionTable[	2715	] = 	-13	;
correctionTable[	2716	] = 	-13	;
correctionTable[	2717	] = 	-13	;
correctionTable[	2718	] = 	-13	;
correctionTable[	2719	] = 	-13	;
correctionTable[	2720	] = 	-13	;
correctionTable[	2721	] = 	-13	;
correctionTable[	2722	] = 	-13	;
correctionTable[	2723	] = 	-13	;
correctionTable[	2724	] = 	-13	;
correctionTable[	2725	] = 	-12	;
correctionTable[	2726	] = 	-12	;
correctionTable[	2727	] = 	-12	;
correctionTable[	2728	] = 	-12	;
correctionTable[	2729	] = 	-12	;
correctionTable[	2730	] = 	-12	;
correctionTable[	2731	] = 	-12	;
correctionTable[	2732	] = 	-12	;
correctionTable[	2733	] = 	-12	;
correctionTable[	2734	] = 	-12	;
correctionTable[	2735	] = 	-12	;
correctionTable[	2736	] = 	-12	;
correctionTable[	2737	] = 	-12	;
correctionTable[	2738	] = 	-12	;
correctionTable[	2739	] = 	-12	;
correctionTable[	2740	] = 	-12	;
correctionTable[	2741	] = 	-12	;
correctionTable[	2742	] = 	-12	;
correctionTable[	2743	] = 	-12	;
correctionTable[	2744	] = 	-12	;
correctionTable[	2745	] = 	-12	;
correctionTable[	2746	] = 	-12	;
correctionTable[	2747	] = 	-12	;
correctionTable[	2748	] = 	-12	;
correctionTable[	2749	] = 	-12	;
correctionTable[	2750	] = 	-12	;
correctionTable[	2751	] = 	-12	;
correctionTable[	2752	] = 	-12	;
correctionTable[	2753	] = 	-12	;
correctionTable[	2754	] = 	-12	;
correctionTable[	2755	] = 	-12	;
correctionTable[	2756	] = 	-12	;
correctionTable[	2757	] = 	-12	;
correctionTable[	2758	] = 	-12	;
correctionTable[	2759	] = 	-12	;
correctionTable[	2760	] = 	-12	;
correctionTable[	2761	] = 	-12	;
correctionTable[	2762	] = 	-12	;
correctionTable[	2763	] = 	-12	;
correctionTable[	2764	] = 	-12	;
correctionTable[	2765	] = 	-12	;
correctionTable[	2766	] = 	-12	;
correctionTable[	2767	] = 	-12	;
correctionTable[	2768	] = 	-12	;
correctionTable[	2769	] = 	-12	;
correctionTable[	2770	] = 	-12	;
correctionTable[	2771	] = 	-12	;
correctionTable[	2772	] = 	-12	;
correctionTable[	2773	] = 	-12	;
correctionTable[	2774	] = 	-12	;
correctionTable[	2775	] = 	-12	;
correctionTable[	2776	] = 	-12	;
correctionTable[	2777	] = 	-12	;
correctionTable[	2778	] = 	-12	;
correctionTable[	2779	] = 	-12	;
correctionTable[	2780	] = 	-12	;
correctionTable[	2781	] = 	-12	;
correctionTable[	2782	] = 	-12	;
correctionTable[	2783	] = 	-12	;
correctionTable[	2784	] = 	-12	;
correctionTable[	2785	] = 	-12	;
correctionTable[	2786	] = 	-12	;
correctionTable[	2787	] = 	-12	;
correctionTable[	2788	] = 	-12	;
correctionTable[	2789	] = 	-12	;
correctionTable[	2790	] = 	-12	;
correctionTable[	2791	] = 	-12	;
correctionTable[	2792	] = 	-12	;
correctionTable[	2793	] = 	-12	;
correctionTable[	2794	] = 	-12	;
correctionTable[	2795	] = 	-12	;
correctionTable[	2796	] = 	-12	;
correctionTable[	2797	] = 	-12	;
correctionTable[	2798	] = 	-12	;
correctionTable[	2799	] = 	-12	;
correctionTable[	2800	] = 	-12	;
correctionTable[	2801	] = 	-12	;
correctionTable[	2802	] = 	-12	;
correctionTable[	2803	] = 	-12	;
correctionTable[	2804	] = 	-12	;
correctionTable[	2805	] = 	-12	;
correctionTable[	2806	] = 	-12	;
correctionTable[	2807	] = 	-12	;
correctionTable[	2808	] = 	-12	;
correctionTable[	2809	] = 	-12	;
correctionTable[	2810	] = 	-12	;
correctionTable[	2811	] = 	-12	;
correctionTable[	2812	] = 	-12	;
correctionTable[	2813	] = 	-12	;
correctionTable[	2814	] = 	-12	;
correctionTable[	2815	] = 	-12	;
correctionTable[	2816	] = 	-12	;
correctionTable[	2817	] = 	-12	;
correctionTable[	2818	] = 	-12	;
correctionTable[	2819	] = 	-12	;
correctionTable[	2820	] = 	-12	;
correctionTable[	2821	] = 	-12	;
correctionTable[	2822	] = 	-12	;
correctionTable[	2823	] = 	-12	;
correctionTable[	2824	] = 	-12	;
correctionTable[	2825	] = 	-12	;
correctionTable[	2826	] = 	-12	;
correctionTable[	2827	] = 	-11	;
correctionTable[	2828	] = 	-11	;
correctionTable[	2829	] = 	-11	;
correctionTable[	2830	] = 	-11	;
correctionTable[	2831	] = 	-11	;
correctionTable[	2832	] = 	-11	;
correctionTable[	2833	] = 	-11	;
correctionTable[	2834	] = 	-11	;
correctionTable[	2835	] = 	-11	;
correctionTable[	2836	] = 	-11	;
correctionTable[	2837	] = 	-11	;
correctionTable[	2838	] = 	-11	;
correctionTable[	2839	] = 	-11	;
correctionTable[	2840	] = 	-11	;
correctionTable[	2841	] = 	-11	;
correctionTable[	2842	] = 	-11	;
correctionTable[	2843	] = 	-11	;
correctionTable[	2844	] = 	-11	;
correctionTable[	2845	] = 	-11	;
correctionTable[	2846	] = 	-11	;
correctionTable[	2847	] = 	-11	;
correctionTable[	2848	] = 	-11	;
correctionTable[	2849	] = 	-11	;
correctionTable[	2850	] = 	-11	;
correctionTable[	2851	] = 	-11	;
correctionTable[	2852	] = 	-11	;
correctionTable[	2853	] = 	-11	;
correctionTable[	2854	] = 	-11	;
correctionTable[	2855	] = 	-11	;
correctionTable[	2856	] = 	-11	;
correctionTable[	2857	] = 	-11	;
correctionTable[	2858	] = 	-11	;
correctionTable[	2859	] = 	-11	;
correctionTable[	2860	] = 	-11	;
correctionTable[	2861	] = 	-11	;
correctionTable[	2862	] = 	-11	;
correctionTable[	2863	] = 	-11	;
correctionTable[	2864	] = 	-11	;
correctionTable[	2865	] = 	-11	;
correctionTable[	2866	] = 	-11	;
correctionTable[	2867	] = 	-11	;
correctionTable[	2868	] = 	-11	;
correctionTable[	2869	] = 	-11	;
correctionTable[	2870	] = 	-11	;
correctionTable[	2871	] = 	-11	;
correctionTable[	2872	] = 	-11	;
correctionTable[	2873	] = 	-11	;
correctionTable[	2874	] = 	-11	;
correctionTable[	2875	] = 	-11	;
correctionTable[	2876	] = 	-11	;
correctionTable[	2877	] = 	-11	;
correctionTable[	2878	] = 	-11	;
correctionTable[	2879	] = 	-11	;
correctionTable[	2880	] = 	-11	;
correctionTable[	2881	] = 	-11	;
correctionTable[	2882	] = 	-11	;
correctionTable[	2883	] = 	-11	;
correctionTable[	2884	] = 	-11	;
correctionTable[	2885	] = 	-11	;
correctionTable[	2886	] = 	-11	;
correctionTable[	2887	] = 	-11	;
correctionTable[	2888	] = 	-11	;
correctionTable[	2889	] = 	-11	;
correctionTable[	2890	] = 	-11	;
correctionTable[	2891	] = 	-11	;
correctionTable[	2892	] = 	-11	;
correctionTable[	2893	] = 	-10	;
correctionTable[	2894	] = 	-10	;
correctionTable[	2895	] = 	-10	;
correctionTable[	2896	] = 	-10	;
correctionTable[	2897	] = 	-10	;
correctionTable[	2898	] = 	-10	;
correctionTable[	2899	] = 	-10	;
correctionTable[	2900	] = 	-10	;
correctionTable[	2901	] = 	-10	;
correctionTable[	2902	] = 	-10	;
correctionTable[	2903	] = 	-10	;
correctionTable[	2904	] = 	-10	;
correctionTable[	2905	] = 	-10	;
correctionTable[	2906	] = 	-10	;
correctionTable[	2907	] = 	-10	;
correctionTable[	2908	] = 	-10	;
correctionTable[	2909	] = 	-10	;
correctionTable[	2910	] = 	-10	;
correctionTable[	2911	] = 	-10	;
correctionTable[	2912	] = 	-10	;
correctionTable[	2913	] = 	-10	;
correctionTable[	2914	] = 	-10	;
correctionTable[	2915	] = 	-10	;
correctionTable[	2916	] = 	-10	;
correctionTable[	2917	] = 	-10	;
correctionTable[	2918	] = 	-10	;
correctionTable[	2919	] = 	-10	;
correctionTable[	2920	] = 	-10	;
correctionTable[	2921	] = 	-10	;
correctionTable[	2922	] = 	-10	;
correctionTable[	2923	] = 	-10	;
correctionTable[	2924	] = 	-10	;
correctionTable[	2925	] = 	-10	;
correctionTable[	2926	] = 	-10	;
correctionTable[	2927	] = 	-10	;
correctionTable[	2928	] = 	-10	;
correctionTable[	2929	] = 	-10	;
correctionTable[	2930	] = 	-10	;
correctionTable[	2931	] = 	-10	;
correctionTable[	2932	] = 	-10	;
correctionTable[	2933	] = 	-10	;
correctionTable[	2934	] = 	-10	;
correctionTable[	2935	] = 	-10	;
correctionTable[	2936	] = 	-10	;
correctionTable[	2937	] = 	-10	;
correctionTable[	2938	] = 	-10	;
correctionTable[	2939	] = 	-10	;
correctionTable[	2940	] = 	-10	;
correctionTable[	2941	] = 	-10	;
correctionTable[	2942	] = 	-10	;
correctionTable[	2943	] = 	-10	;
correctionTable[	2944	] = 	-10	;
correctionTable[	2945	] = 	-10	;
correctionTable[	2946	] = 	-9	;
correctionTable[	2947	] = 	-9	;
correctionTable[	2948	] = 	-9	;
correctionTable[	2949	] = 	-9	;
correctionTable[	2950	] = 	-9	;
correctionTable[	2951	] = 	-9	;
correctionTable[	2952	] = 	-9	;
correctionTable[	2953	] = 	-9	;
correctionTable[	2954	] = 	-9	;
correctionTable[	2955	] = 	-9	;
correctionTable[	2956	] = 	-9	;
correctionTable[	2957	] = 	-9	;
correctionTable[	2958	] = 	-9	;
correctionTable[	2959	] = 	-9	;
correctionTable[	2960	] = 	-9	;
correctionTable[	2961	] = 	-9	;
correctionTable[	2962	] = 	-9	;
correctionTable[	2963	] = 	-9	;
correctionTable[	2964	] = 	-9	;
correctionTable[	2965	] = 	-9	;
correctionTable[	2966	] = 	-9	;
correctionTable[	2967	] = 	-9	;
correctionTable[	2968	] = 	-9	;
correctionTable[	2969	] = 	-9	;
correctionTable[	2970	] = 	-9	;
correctionTable[	2971	] = 	-9	;
correctionTable[	2972	] = 	-9	;
correctionTable[	2973	] = 	-9	;
correctionTable[	2974	] = 	-9	;
correctionTable[	2975	] = 	-9	;
correctionTable[	2976	] = 	-9	;
correctionTable[	2977	] = 	-9	;
correctionTable[	2978	] = 	-9	;
correctionTable[	2979	] = 	-9	;
correctionTable[	2980	] = 	-9	;
correctionTable[	2981	] = 	-9	;
correctionTable[	2982	] = 	-9	;
correctionTable[	2983	] = 	-9	;
correctionTable[	2984	] = 	-9	;
correctionTable[	2985	] = 	-9	;
correctionTable[	2986	] = 	-9	;
correctionTable[	2987	] = 	-9	;
correctionTable[	2988	] = 	-9	;
correctionTable[	2989	] = 	-9	;
correctionTable[	2990	] = 	-8	;
correctionTable[	2991	] = 	-8	;
correctionTable[	2992	] = 	-8	;
correctionTable[	2993	] = 	-8	;
correctionTable[	2994	] = 	-8	;
correctionTable[	2995	] = 	-8	;
correctionTable[	2996	] = 	-8	;
correctionTable[	2997	] = 	-8	;
correctionTable[	2998	] = 	-8	;
correctionTable[	2999	] = 	-8	;
correctionTable[	3000	] = 	-8	;
correctionTable[	3001	] = 	-8	;
correctionTable[	3002	] = 	-8	;
correctionTable[	3003	] = 	-8	;
correctionTable[	3004	] = 	-8	;
correctionTable[	3005	] = 	-8	;
correctionTable[	3006	] = 	-8	;
correctionTable[	3007	] = 	-8	;
correctionTable[	3008	] = 	-8	;
correctionTable[	3009	] = 	-8	;
correctionTable[	3010	] = 	-8	;
correctionTable[	3011	] = 	-8	;
correctionTable[	3012	] = 	-8	;
correctionTable[	3013	] = 	-8	;
correctionTable[	3014	] = 	-8	;
correctionTable[	3015	] = 	-8	;
correctionTable[	3016	] = 	-8	;
correctionTable[	3017	] = 	-8	;
correctionTable[	3018	] = 	-8	;
correctionTable[	3019	] = 	-8	;
correctionTable[	3020	] = 	-8	;
correctionTable[	3021	] = 	-8	;
correctionTable[	3022	] = 	-8	;
correctionTable[	3023	] = 	-8	;
correctionTable[	3024	] = 	-8	;
correctionTable[	3025	] = 	-8	;
correctionTable[	3026	] = 	-8	;
correctionTable[	3027	] = 	-8	;
correctionTable[	3028	] = 	-8	;
correctionTable[	3029	] = 	-7	;
correctionTable[	3030	] = 	-7	;
correctionTable[	3031	] = 	-7	;
correctionTable[	3032	] = 	-7	;
correctionTable[	3033	] = 	-7	;
correctionTable[	3034	] = 	-7	;
correctionTable[	3035	] = 	-7	;
correctionTable[	3036	] = 	-7	;
correctionTable[	3037	] = 	-7	;
correctionTable[	3038	] = 	-7	;
correctionTable[	3039	] = 	-7	;
correctionTable[	3040	] = 	-7	;
correctionTable[	3041	] = 	-7	;
correctionTable[	3042	] = 	-7	;
correctionTable[	3043	] = 	-7	;
correctionTable[	3044	] = 	-7	;
correctionTable[	3045	] = 	-7	;
correctionTable[	3046	] = 	-7	;
correctionTable[	3047	] = 	-7	;
correctionTable[	3048	] = 	-7	;
correctionTable[	3049	] = 	-7	;
correctionTable[	3050	] = 	-7	;
correctionTable[	3051	] = 	-7	;
correctionTable[	3052	] = 	-7	;
correctionTable[	3053	] = 	-7	;
correctionTable[	3054	] = 	-7	;
correctionTable[	3055	] = 	-7	;
correctionTable[	3056	] = 	-7	;
correctionTable[	3057	] = 	-7	;
correctionTable[	3058	] = 	-7	;
correctionTable[	3059	] = 	-7	;
correctionTable[	3060	] = 	-7	;
correctionTable[	3061	] = 	-7	;
correctionTable[	3062	] = 	-7	;
correctionTable[	3063	] = 	-7	;
correctionTable[	3064	] = 	-6	;
correctionTable[	3065	] = 	-6	;
correctionTable[	3066	] = 	-6	;
correctionTable[	3067	] = 	-6	;
correctionTable[	3068	] = 	-6	;
correctionTable[	3069	] = 	-6	;
correctionTable[	3070	] = 	-6	;
correctionTable[	3071	] = 	-6	;
correctionTable[	3072	] = 	-6	;
correctionTable[	3073	] = 	-6	;
correctionTable[	3074	] = 	-6	;
correctionTable[	3075	] = 	-6	;
correctionTable[	3076	] = 	-6	;
correctionTable[	3077	] = 	-6	;
correctionTable[	3078	] = 	-6	;
correctionTable[	3079	] = 	-6	;
correctionTable[	3080	] = 	-6	;
correctionTable[	3081	] = 	-6	;
correctionTable[	3082	] = 	-6	;
correctionTable[	3083	] = 	-6	;
correctionTable[	3084	] = 	-6	;
correctionTable[	3085	] = 	-6	;
correctionTable[	3086	] = 	-6	;
correctionTable[	3087	] = 	-6	;
correctionTable[	3088	] = 	-6	;
correctionTable[	3089	] = 	-6	;
correctionTable[	3090	] = 	-6	;
correctionTable[	3091	] = 	-6	;
correctionTable[	3092	] = 	-6	;
correctionTable[	3093	] = 	-6	;
correctionTable[	3094	] = 	-6	;
correctionTable[	3095	] = 	-6	;
correctionTable[	3096	] = 	-6	;
correctionTable[	3097	] = 	-5	;
correctionTable[	3098	] = 	-5	;
correctionTable[	3099	] = 	-5	;
correctionTable[	3100	] = 	-5	;
correctionTable[	3101	] = 	-5	;
correctionTable[	3102	] = 	-5	;
correctionTable[	3103	] = 	-5	;
correctionTable[	3104	] = 	-5	;
correctionTable[	3105	] = 	-5	;
correctionTable[	3106	] = 	-5	;
correctionTable[	3107	] = 	-5	;
correctionTable[	3108	] = 	-5	;
correctionTable[	3109	] = 	-5	;
correctionTable[	3110	] = 	-5	;
correctionTable[	3111	] = 	-5	;
correctionTable[	3112	] = 	-5	;
correctionTable[	3113	] = 	-5	;
correctionTable[	3114	] = 	-5	;
correctionTable[	3115	] = 	-5	;
correctionTable[	3116	] = 	-5	;
correctionTable[	3117	] = 	-5	;
correctionTable[	3118	] = 	-5	;
correctionTable[	3119	] = 	-5	;
correctionTable[	3120	] = 	-5	;
correctionTable[	3121	] = 	-5	;
correctionTable[	3122	] = 	-5	;
correctionTable[	3123	] = 	-5	;
correctionTable[	3124	] = 	-5	;
correctionTable[	3125	] = 	-5	;
correctionTable[	3126	] = 	-5	;
correctionTable[	3127	] = 	-4	;
correctionTable[	3128	] = 	-4	;
correctionTable[	3129	] = 	-4	;
correctionTable[	3130	] = 	-4	;
correctionTable[	3131	] = 	-4	;
correctionTable[	3132	] = 	-4	;
correctionTable[	3133	] = 	-4	;
correctionTable[	3134	] = 	-4	;
correctionTable[	3135	] = 	-4	;
correctionTable[	3136	] = 	-4	;
correctionTable[	3137	] = 	-4	;
correctionTable[	3138	] = 	-4	;
correctionTable[	3139	] = 	-4	;
correctionTable[	3140	] = 	-4	;
correctionTable[	3141	] = 	-4	;
correctionTable[	3142	] = 	-4	;
correctionTable[	3143	] = 	-4	;
correctionTable[	3144	] = 	-4	;
correctionTable[	3145	] = 	-4	;
correctionTable[	3146	] = 	-4	;
correctionTable[	3147	] = 	-4	;
correctionTable[	3148	] = 	-4	;
correctionTable[	3149	] = 	-4	;
correctionTable[	3150	] = 	-4	;
correctionTable[	3151	] = 	-4	;
correctionTable[	3152	] = 	-4	;
correctionTable[	3153	] = 	-4	;
correctionTable[	3154	] = 	-4	;
correctionTable[	3155	] = 	-3	;
correctionTable[	3156	] = 	-3	;
correctionTable[	3157	] = 	-3	;
correctionTable[	3158	] = 	-3	;
correctionTable[	3159	] = 	-3	;
correctionTable[	3160	] = 	-3	;
correctionTable[	3161	] = 	-3	;
correctionTable[	3162	] = 	-3	;
correctionTable[	3163	] = 	-3	;
correctionTable[	3164	] = 	-3	;
correctionTable[	3165	] = 	-3	;
correctionTable[	3166	] = 	-3	;
correctionTable[	3167	] = 	-3	;
correctionTable[	3168	] = 	-3	;
correctionTable[	3169	] = 	-3	;
correctionTable[	3170	] = 	-3	;
correctionTable[	3171	] = 	-3	;
correctionTable[	3172	] = 	-3	;
correctionTable[	3173	] = 	-3	;
correctionTable[	3174	] = 	-3	;
correctionTable[	3175	] = 	-3	;
correctionTable[	3176	] = 	-3	;
correctionTable[	3177	] = 	-3	;
correctionTable[	3178	] = 	-3	;
correctionTable[	3179	] = 	-3	;
correctionTable[	3180	] = 	-3	;
correctionTable[	3181	] = 	-3	;
correctionTable[	3182	] = 	-2	;
correctionTable[	3183	] = 	-2	;
correctionTable[	3184	] = 	-2	;
correctionTable[	3185	] = 	-2	;
correctionTable[	3186	] = 	-2	;
correctionTable[	3187	] = 	-2	;
correctionTable[	3188	] = 	-2	;
correctionTable[	3189	] = 	-2	;
correctionTable[	3190	] = 	-2	;
correctionTable[	3191	] = 	-2	;
correctionTable[	3192	] = 	-2	;
correctionTable[	3193	] = 	-2	;
correctionTable[	3194	] = 	-2	;
correctionTable[	3195	] = 	-2	;
correctionTable[	3196	] = 	-2	;
correctionTable[	3197	] = 	-2	;
correctionTable[	3198	] = 	-2	;
correctionTable[	3199	] = 	-2	;
correctionTable[	3200	] = 	-2	;
correctionTable[	3201	] = 	-2	;
correctionTable[	3202	] = 	-2	;
correctionTable[	3203	] = 	-2	;
correctionTable[	3204	] = 	-2	;
correctionTable[	3205	] = 	-2	;
correctionTable[	3206	] = 	-2	;
correctionTable[	3207	] = 	-2	;
correctionTable[	3208	] = 	-1	;
correctionTable[	3209	] = 	-1	;
correctionTable[	3210	] = 	-1	;
correctionTable[	3211	] = 	-1	;
correctionTable[	3212	] = 	-1	;
correctionTable[	3213	] = 	-1	;
correctionTable[	3214	] = 	-1	;
correctionTable[	3215	] = 	-1	;
correctionTable[	3216	] = 	-1	;
correctionTable[	3217	] = 	-1	;
correctionTable[	3218	] = 	-1	;
correctionTable[	3219	] = 	-1	;
correctionTable[	3220	] = 	-1	;
correctionTable[	3221	] = 	-1	;
correctionTable[	3222	] = 	-1	;
correctionTable[	3223	] = 	-1	;
correctionTable[	3224	] = 	-1	;
correctionTable[	3225	] = 	-1	;
correctionTable[	3226	] = 	-1	;
correctionTable[	3227	] = 	-1	;
correctionTable[	3228	] = 	-1	;
correctionTable[	3229	] = 	-1	;
correctionTable[	3230	] = 	-1	;
correctionTable[	3231	] = 	-1	;
correctionTable[	3232	] = 	-1	;
correctionTable[	3233	] = 	0	;
correctionTable[	3234	] = 	0	;
correctionTable[	3235	] = 	0	;
correctionTable[	3236	] = 	0	;
correctionTable[	3237	] = 	0	;
correctionTable[	3238	] = 	0	;
correctionTable[	3239	] = 	0	;
correctionTable[	3240	] = 	0	;
correctionTable[	3241	] = 	0	;
correctionTable[	3242	] = 	0	;
correctionTable[	3243	] = 	0	;
correctionTable[	3244	] = 	0	;
correctionTable[	3245	] = 	0	;
correctionTable[	3246	] = 	0	;
correctionTable[	3247	] = 	0	;
correctionTable[	3248	] = 	0	;
correctionTable[	3249	] = 	0	;
correctionTable[	3250	] = 	0	;
correctionTable[	3251	] = 	0	;
correctionTable[	3252	] = 	0	;
correctionTable[	3253	] = 	0	;
correctionTable[	3254	] = 	0	;
correctionTable[	3255	] = 	0	;
correctionTable[	3256	] = 	0	;
correctionTable[	3257	] = 	1	;
correctionTable[	3258	] = 	1	;
correctionTable[	3259	] = 	1	;
correctionTable[	3260	] = 	1	;
correctionTable[	3261	] = 	1	;
correctionTable[	3262	] = 	1	;
correctionTable[	3263	] = 	1	;
correctionTable[	3264	] = 	1	;
correctionTable[	3265	] = 	1	;
correctionTable[	3266	] = 	1	;
correctionTable[	3267	] = 	1	;
correctionTable[	3268	] = 	1	;
correctionTable[	3269	] = 	1	;
correctionTable[	3270	] = 	1	;
correctionTable[	3271	] = 	1	;
correctionTable[	3272	] = 	1	;
correctionTable[	3273	] = 	1	;
correctionTable[	3274	] = 	1	;
correctionTable[	3275	] = 	1	;
correctionTable[	3276	] = 	1	;
correctionTable[	3277	] = 	1	;
correctionTable[	3278	] = 	1	;
correctionTable[	3279	] = 	1	;
correctionTable[	3280	] = 	2	;
correctionTable[	3281	] = 	2	;
correctionTable[	3282	] = 	2	;
correctionTable[	3283	] = 	2	;
correctionTable[	3284	] = 	2	;
correctionTable[	3285	] = 	2	;
correctionTable[	3286	] = 	2	;
correctionTable[	3287	] = 	2	;
correctionTable[	3288	] = 	2	;
correctionTable[	3289	] = 	2	;
correctionTable[	3290	] = 	2	;
correctionTable[	3291	] = 	2	;
correctionTable[	3292	] = 	2	;
correctionTable[	3293	] = 	2	;
correctionTable[	3294	] = 	2	;
correctionTable[	3295	] = 	2	;
correctionTable[	3296	] = 	2	;
correctionTable[	3297	] = 	2	;
correctionTable[	3298	] = 	2	;
correctionTable[	3299	] = 	2	;
correctionTable[	3300	] = 	2	;
correctionTable[	3301	] = 	2	;
correctionTable[	3302	] = 	3	;
correctionTable[	3303	] = 	3	;
correctionTable[	3304	] = 	3	;
correctionTable[	3305	] = 	3	;
correctionTable[	3306	] = 	3	;
correctionTable[	3307	] = 	3	;
correctionTable[	3308	] = 	3	;
correctionTable[	3309	] = 	3	;
correctionTable[	3310	] = 	3	;
correctionTable[	3311	] = 	3	;
correctionTable[	3312	] = 	3	;
correctionTable[	3313	] = 	3	;
correctionTable[	3314	] = 	3	;
correctionTable[	3315	] = 	3	;
correctionTable[	3316	] = 	3	;
correctionTable[	3317	] = 	3	;
correctionTable[	3318	] = 	3	;
correctionTable[	3319	] = 	3	;
correctionTable[	3320	] = 	3	;
correctionTable[	3321	] = 	3	;
correctionTable[	3322	] = 	3	;
correctionTable[	3323	] = 	3	;
correctionTable[	3324	] = 	4	;
correctionTable[	3325	] = 	4	;
correctionTable[	3326	] = 	4	;
correctionTable[	3327	] = 	4	;
correctionTable[	3328	] = 	4	;
correctionTable[	3329	] = 	4	;
correctionTable[	3330	] = 	4	;
correctionTable[	3331	] = 	4	;
correctionTable[	3332	] = 	4	;
correctionTable[	3333	] = 	4	;
correctionTable[	3334	] = 	4	;
correctionTable[	3335	] = 	4	;
correctionTable[	3336	] = 	4	;
correctionTable[	3337	] = 	4	;
correctionTable[	3338	] = 	4	;
correctionTable[	3339	] = 	4	;
correctionTable[	3340	] = 	4	;
correctionTable[	3341	] = 	4	;
correctionTable[	3342	] = 	4	;
correctionTable[	3343	] = 	4	;
correctionTable[	3344	] = 	4	;
correctionTable[	3345	] = 	5	;
correctionTable[	3346	] = 	5	;
correctionTable[	3347	] = 	5	;
correctionTable[	3348	] = 	5	;
correctionTable[	3349	] = 	5	;
correctionTable[	3350	] = 	5	;
correctionTable[	3351	] = 	5	;
correctionTable[	3352	] = 	5	;
correctionTable[	3353	] = 	5	;
correctionTable[	3354	] = 	5	;
correctionTable[	3355	] = 	5	;
correctionTable[	3356	] = 	5	;
correctionTable[	3357	] = 	5	;
correctionTable[	3358	] = 	5	;
correctionTable[	3359	] = 	5	;
correctionTable[	3360	] = 	5	;
correctionTable[	3361	] = 	5	;
correctionTable[	3362	] = 	5	;
correctionTable[	3363	] = 	5	;
correctionTable[	3364	] = 	5	;
correctionTable[	3365	] = 	5	;
correctionTable[	3366	] = 	6	;
correctionTable[	3367	] = 	6	;
correctionTable[	3368	] = 	6	;
correctionTable[	3369	] = 	6	;
correctionTable[	3370	] = 	6	;
correctionTable[	3371	] = 	6	;
correctionTable[	3372	] = 	6	;
correctionTable[	3373	] = 	6	;
correctionTable[	3374	] = 	6	;
correctionTable[	3375	] = 	6	;
correctionTable[	3376	] = 	6	;
correctionTable[	3377	] = 	6	;
correctionTable[	3378	] = 	6	;
correctionTable[	3379	] = 	6	;
correctionTable[	3380	] = 	6	;
correctionTable[	3381	] = 	6	;
correctionTable[	3382	] = 	6	;
correctionTable[	3383	] = 	6	;
correctionTable[	3384	] = 	6	;
correctionTable[	3385	] = 	6	;
correctionTable[	3386	] = 	7	;
correctionTable[	3387	] = 	7	;
correctionTable[	3388	] = 	7	;
correctionTable[	3389	] = 	7	;
correctionTable[	3390	] = 	7	;
correctionTable[	3391	] = 	7	;
correctionTable[	3392	] = 	7	;
correctionTable[	3393	] = 	7	;
correctionTable[	3394	] = 	7	;
correctionTable[	3395	] = 	7	;
correctionTable[	3396	] = 	7	;
correctionTable[	3397	] = 	7	;
correctionTable[	3398	] = 	7	;
correctionTable[	3399	] = 	7	;
correctionTable[	3400	] = 	7	;
correctionTable[	3401	] = 	7	;
correctionTable[	3402	] = 	7	;
correctionTable[	3403	] = 	7	;
correctionTable[	3404	] = 	7	;
correctionTable[	3405	] = 	7	;
correctionTable[	3406	] = 	8	;
correctionTable[	3407	] = 	8	;
correctionTable[	3408	] = 	8	;
correctionTable[	3409	] = 	8	;
correctionTable[	3410	] = 	8	;
correctionTable[	3411	] = 	8	;
correctionTable[	3412	] = 	8	;
correctionTable[	3413	] = 	8	;
correctionTable[	3414	] = 	8	;
correctionTable[	3415	] = 	8	;
correctionTable[	3416	] = 	8	;
correctionTable[	3417	] = 	8	;
correctionTable[	3418	] = 	8	;
correctionTable[	3419	] = 	8	;
correctionTable[	3420	] = 	8	;
correctionTable[	3421	] = 	8	;
correctionTable[	3422	] = 	8	;
correctionTable[	3423	] = 	8	;
correctionTable[	3424	] = 	8	;
correctionTable[	3425	] = 	8	;
correctionTable[	3426	] = 	9	;
correctionTable[	3427	] = 	9	;
correctionTable[	3428	] = 	9	;
correctionTable[	3429	] = 	9	;
correctionTable[	3430	] = 	9	;
correctionTable[	3431	] = 	9	;
correctionTable[	3432	] = 	9	;
correctionTable[	3433	] = 	9	;
correctionTable[	3434	] = 	9	;
correctionTable[	3435	] = 	9	;
correctionTable[	3436	] = 	9	;
correctionTable[	3437	] = 	9	;
correctionTable[	3438	] = 	9	;
correctionTable[	3439	] = 	9	;
correctionTable[	3440	] = 	9	;
correctionTable[	3441	] = 	9	;
correctionTable[	3442	] = 	9	;
correctionTable[	3443	] = 	9	;
correctionTable[	3444	] = 	9	;
correctionTable[	3445	] = 	9	;
correctionTable[	3446	] = 	10	;
correctionTable[	3447	] = 	10	;
correctionTable[	3448	] = 	10	;
correctionTable[	3449	] = 	10	;
correctionTable[	3450	] = 	10	;
correctionTable[	3451	] = 	10	;
correctionTable[	3452	] = 	10	;
correctionTable[	3453	] = 	10	;
correctionTable[	3454	] = 	10	;
correctionTable[	3455	] = 	10	;
correctionTable[	3456	] = 	10	;
correctionTable[	3457	] = 	10	;
correctionTable[	3458	] = 	10	;
correctionTable[	3459	] = 	10	;
correctionTable[	3460	] = 	10	;
correctionTable[	3461	] = 	10	;
correctionTable[	3462	] = 	10	;
correctionTable[	3463	] = 	10	;
correctionTable[	3464	] = 	10	;
correctionTable[	3465	] = 	11	;
correctionTable[	3466	] = 	11	;
correctionTable[	3467	] = 	11	;
correctionTable[	3468	] = 	11	;
correctionTable[	3469	] = 	11	;
correctionTable[	3470	] = 	11	;
correctionTable[	3471	] = 	11	;
correctionTable[	3472	] = 	11	;
correctionTable[	3473	] = 	11	;
correctionTable[	3474	] = 	11	;
correctionTable[	3475	] = 	11	;
correctionTable[	3476	] = 	11	;
correctionTable[	3477	] = 	11	;
correctionTable[	3478	] = 	11	;
correctionTable[	3479	] = 	11	;
correctionTable[	3480	] = 	11	;
correctionTable[	3481	] = 	11	;
correctionTable[	3482	] = 	11	;
correctionTable[	3483	] = 	11	;
correctionTable[	3484	] = 	11	;
correctionTable[	3485	] = 	12	;
correctionTable[	3486	] = 	12	;
correctionTable[	3487	] = 	12	;
correctionTable[	3488	] = 	12	;
correctionTable[	3489	] = 	12	;
correctionTable[	3490	] = 	12	;
correctionTable[	3491	] = 	12	;
correctionTable[	3492	] = 	12	;
correctionTable[	3493	] = 	12	;
correctionTable[	3494	] = 	12	;
correctionTable[	3495	] = 	12	;
correctionTable[	3496	] = 	12	;
correctionTable[	3497	] = 	12	;
correctionTable[	3498	] = 	12	;
correctionTable[	3499	] = 	12	;
correctionTable[	3500	] = 	12	;

}
