/*********************************************************
* function.c - functions for meansuring
*
* v_0.1
*
* Copyright (c)2014 Matej Z. All rights reserved.
* matej.zdenek@gmail.com
*********************************************************/

#include "params.h"

#include "getopt.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

void SetDefaultParamsValue(ParamsStruct *params)
{
	params->ZPUSOB_NACITANI_DAT_VSTUPNI_UDP_PORT = 0;
	params->SOUBOR1 = "in1.dat";      //nazev souboru HIGH
	params->SOUBOR2 = "in2.dat";		//nazev souboru LOW
	params->SOUBOR_OUT = "out.csv";	//nazev vystupniho souboru
	params->ODESILAT_DATA_VYSTUPNI_UDP_PORT = 0;
	params->OUTPUT_IP = "127.0.0.1";
	params->STATS_INTERVAL_MS = 1000;
	params->METODA = 1; 	//integracni
	params->POCET_IMPULSU = 0;	//pocet impulzu k nacteni (0 - neomezene nacitani)
	params->KONSTANTA_NASOBENI = 0;
	params->ZPRACOVAVANE_SOUBORY = 'B';	//L - jen LOW, H - jen HIGH, B - oba, dojde ke slouceni
	params->SUPERPOSITION_THRESHOLD_BOD_ENERGIE_0 = 0;
	params->SUPERPOSITION_THRESHOLD_BOD_ENERGIE_MAX = 0;
	params->HRANICE_UKLADANI_PULZU = 0;
	params->PARAM_X = 0;		//univerzln parametr
	params->PARAM_Y = 0;		//univerzln parametr
	params->PARAM_Z = 0;		//univerzln parametr
}


void PrintValues(ParamsStruct *params, int vypisHelpu, FILE* file)
{
	char* vHelp = "default";
	char* vValues = "";
	char* v = (vypisHelpu) ? vHelp : vValues;

	fprintf(file, "--------------------------------------------------------------------------------\r\n");
	fprintf(file, "CLASSIFICATOR SCRIPT - zpracovani spektrometrickych dat\r\n\r\n");

	fprintf(file, "-i Vstup (0 - ze souboru, jinak cislo UDP portu)       %s %d\r\n", v, params->ZPUSOB_NACITANI_DAT_VSTUPNI_UDP_PORT);
	fprintf(file, "-f nacitany soubor HIGH                                %s %s\r\n", v, params->SOUBOR1);
	fprintf(file, "-d nacitany soubor LOW                                 %s %s\r\n", v, params->SOUBOR2);
	fprintf(file, "-o vystupni soubor (0 - neukladat)                     %s %s\r\n", v, params->SOUBOR_OUT);
	fprintf(file, "-u vystup pres UDP (0-neposilat, jinak UDP port)       %s %d\r\n", v, params->ODESILAT_DATA_VYSTUPNI_UDP_PORT);
	fprintf(file, "-a IP adresa kam posilat odchozi pakety                %s %s\r\n", v, params->OUTPUT_IP);
	fprintf(file, "-b perioda vypisovani aktualni statistiky [ms]         %s %d\r\n", v, params->STATS_INTERVAL_MS);
	fprintf(file, "-m metoda zpracovani                                   %s %d\r\n", v, params->METODA);
	fprintf(file, "         1 - integracni metoda                              \r\n");
	fprintf(file, "         2 - WBO                              \r\n");
	fprintf(file, "-p pocet impulsu ktere chceme nacitat (0-nacte vse)    %s %d\r\n", v, params->POCET_IMPULSU);
	fprintf(file, "-k pomer zesileni predzesilovace (0-automaticky)       %s %3.3f\r\n", v, params->KONSTANTA_NASOBENI);
	fprintf(file, "-s zpracovavane soubory (L-LOW, H-HIGH, B-oba)         %s %c\r\n", v, params->ZPRACOVAVANE_SOUBORY);
	fprintf(file, "-t threshold superpozice na energii 0                  %s %d\r\n", v, params->SUPERPOSITION_THRESHOLD_BOD_ENERGIE_0);
	fprintf(file, "        (typicky 500, 0-vypnuta detekce superpozic)\r\n");
	fprintf(file, "-v threshold superpozice na max energii (typicky 2500) %s %d\r\n", v, params->SUPERPOSITION_THRESHOLD_BOD_ENERGIE_MAX);
	fprintf(file, "-c hranice pro ulozeni pulzu na disk (0-vypnuto)       %s %lld\n", v, params->HRANICE_UKLADANI_PULZU);
	fprintf(file, "        <min E><max E><min discrP><max discrP>\r\n");
    fprintf(file, "        (vzdy 4 cislice, zadavat bez mezer)\r\n");
	fprintf(file, "-x uzivatelsky integer parametr                        %s %d\r\n", v, params->PARAM_X);
	fprintf(file, "-y uzivatelsky integer parametr                        %s %d\r\n", v, params->PARAM_Y);
	fprintf(file, "-z uzivatelsky integer parametr                        %s %d\r\n", v, params->PARAM_Z);
	fprintf(file, "--------------------------------------------------------------------------------\r\n");
}



int ParseCommandLineParams(int argc, char **argv, ParamsStruct *params)
{
	//default values
	SetDefaultParamsValue(params);


	//Specifying the expected options
	int a;
	long long c;
	float i;
	int option = 0;
    while ((option = getopt(argc, argv,"i:f:d:o:u:m:k:p:hs:x:y:z:a:t:v:b:c:")) != -1) {
        switch (option)
		{
			case 'h' :
		    	 PrintValues(params, 1, stdout);
				 return(0);
                 break;

			 case 'i' : a = atol(optarg);
						if (a >= 0 && a <= 65535){
							params->ZPUSOB_NACITANI_DAT_VSTUPNI_UDP_PORT = a;
						}else {
							printf ("Chybne zadani vstupniho UDP portu. Zadavejte: 0 - 65535. \r\n");
							return(0);
						}
                 break;


			 case 'f' : if (strlen(optarg)>0){
							params->SOUBOR1 = optarg;
						}else {
							printf ("Chybne zadani nazvu souboru HIGH. Zadavejte: -f in1.dat \r\n");
							return(0);
						}
                 break;

			 case 'd' : if (strlen(optarg)>0){
							params->SOUBOR2 = optarg;
						}else {
							printf ("Chybne zadani nazvu souboru LOW. Zadavejte: -d in2.dat \r\n");
							return(0);
						}
                 break;

			case 'o' : if (strlen(optarg)>0){
							params->SOUBOR_OUT = optarg;
						}else {
							printf ("Chybne zadani nazvu vystupniho souboru. Zadavejte napriklad: -o out.csv \r\n");
							return(0);
						}
                 break;


			case 'a' : if (strlen(optarg)>0){
							params->OUTPUT_IP = optarg;
						}else {
							printf ("Chybne zadani odchozi IP. Zadavejte napr: -a 192.168.2.1\r\n");
							return(0);
						}
                 break;

			 case 'm' : a = atol(optarg);
						if ((a >= 1)){
							params->METODA = a;
						}else {
							printf ("Chybne zadani metody zpracovani. Zadavejte vetsi jak 0. \r\n");
							return(0);
						}
                 break;

			case 't' : a = atol(optarg);
						if ((a>=0)){
							params->SUPERPOSITION_THRESHOLD_BOD_ENERGIE_0 = a;
						}else {
							printf ("Chybne zadani thresholdu superpozice na enrgii 0. Zadavejte vetsi nebo rovno jak 0.\r\n");
							return(0);
						}
                 break;

            case 'c' : c = atoll(optarg);
						if ((c>=0)){
							params->HRANICE_UKLADANI_PULZU = c;
						}else {
							printf ("Chybne zadani hranice pro ukladani pulzu. Zadavejte vetsi nebo rovno jak 0.\r\n");
							return(0);
						}
                 break;

			case 'b' : a = atol(optarg);
						if ((a > 0)){
							params->STATS_INTERVAL_MS = a;
						}else {
							printf ("Chybne zadani intervalu statistiky. Zadavejte vetsi jak 0.\r\n");
							return(0);
						}
                 break;

			case 'v' : a = atol(optarg);
						if ((a>=0)){
							params->SUPERPOSITION_THRESHOLD_BOD_ENERGIE_MAX = a;
						}else {
							printf ("Chybne zadani thresholdu superpozice na maximalni energii. Zadavejte vetsi jak 0.\r\n");
							return(0);
						}
                 break;

			 case 'u' : a = atol(optarg);
						if (a >= 0 && a <= 65535){
							params->ODESILAT_DATA_VYSTUPNI_UDP_PORT = a;
						}else {
							printf ("Chybne zadani vystupniho UDP portu. Zadavejte: 0 - 65535. \r\n");
							return(0);
						}
                 break;

			 case 'k' : i = atof(optarg);
				  	if ((i>=0) && (i<=100))
					{
						params->KONSTANTA_NASOBENI = i;
						}else {
							printf ("Chybne zadani koeficientu nasobeni. Zadavejte: 0 - 100. \r\n");
							return(0);
					}
                 break;

              case 'p' :
					a = atol(optarg);
				  	params->POCET_IMPULSU = a;
					if (a < 0)
					{
						params->POCET_IMPULSU = 0; // neomezen natn
					}

                 break;

			case 'x' :
					params->PARAM_X = atol(optarg);
                 break;

			case 'y' :
					params->PARAM_Y = atol(optarg);
                 break;

			case 'z' :
					params->PARAM_Z = atol(optarg);
                 break;

			  case 's':
				    if (strcmp(optarg, "L") == 0)
					{
						params->ZPRACOVAVANE_SOUBORY = 'L';
					}
					else if (strcmp(optarg, "H") == 0)
					{
						params->ZPRACOVAVANE_SOUBORY = 'H';
					}
					else if (strcmp(optarg, "B") == 0)
					{
						params->ZPRACOVAVANE_SOUBORY = 'B';
					}
					else
					{
						fprintf(stderr, "Chybne zadani souboru ke zpracovani. Zadavejte L, H nebo B\r\n");
						return(0);
					}
                 break;

             default:
                 //return(0);
				 break;
        }
    }

	PrintValues(params, 0, stdout);

   return 1;
}
