/*
 *  Project   : SPECTRUM - Digital Spectrometric System of Nuclear Radiation
 *
 *  Tool      : ClassificatorScript - spectrometric data processing
 *
 *  Author(s) : Martin VESKRNA <256569@mail.muni.cz>
 *
 *  Date      :
 *
 *  (c) Copyright 2011 MASARYK UNIVERSITY
 *  All rights reserved.
 *
 *  Please review the terms of the license agreement before using this
 *  file. If you are not an authorized user, please destroy this
 *  source code file and notify MASARYK UNIVERSITY immediately that you
 *  inadvertently received an unauthorized copy.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <math.h>

#include "stats.h"
#include "constants.h"


long long pocitadlo_impulsu_prev = 0;
int stav = 0;
time_t previousTime;
unsigned long long timeOfNextStats_ns = 0;
long long pocitadlo_impulsu = 0;

double timeOfFirstReceivedPulse_sec = 0;

char statsTextActual[50000];
char statsTextTotal[50000];

FILE* statisticsFile = NULL;
int OpenStatisticFile(char* filePrefix)
{
    char nazevSouboru[100];
	sprintf(nazevSouboru, "%.50s%.50s", filePrefix, "_statistics.txt");

 	statisticsFile = fopen(nazevSouboru, "wb");
	if (statisticsFile == NULL)
	{
		fprintf(stderr, "\nCan't open statistic file!\n");
		return(0);
	}

	return 1;
}

FILE* GetStatisticFile()
{
    return statisticsFile;
}

void CloseStatisticFile()
{
    fclose(statisticsFile);
}


void ClearStatLossItem(tStatTimeLossItem *item)
{
    item->numLoss = 0;
    item->numLossImpulses = 0;
    item->maximum_sec = -INFINITY;
    item->minimum_sec = INFINITY;
    item->sum_sec = 0;
    item->sumPow2_sec = 0;
}

void ClearStatItem(tStatTimeItem *item)
{
	item->timeLastImpulse_sec = 0;
	item->timeFirstImpulse_sec = 0;
	item->numberSuperposedImpulses = 0;
	item->numberNotCompletedImpulses = 0;
	item->numberAllImpulses = 0;
	ClearStatLossItem(&item->shortLoss);
	ClearStatLossItem(&item->mediumLoss);
	ClearStatLossItem(&item->longLoss);
}

void TimeClearStatistics(tStatTime *stats, int onlyActual)
{
	ClearStatItem(&stats->actual);

	if (!onlyActual)
	{
		ClearStatItem(&stats->total);
	}
}

void TimeStoreLossStatistics(tStatTimeLossItem *item, unsigned long long vypadek_ns, int vypadek_pulzy)
{
    double vypadek_sec = (double)vypadek_ns / 1000000000.0;

    item->numLossImpulses += (unsigned long long)vypadek_pulzy;
    item->numLoss++;
    item->sum_sec += vypadek_sec;
    item->sumPow2_sec += vypadek_sec * vypadek_sec;
    item->maximum_sec = (item->maximum_sec > vypadek_sec) ? item->maximum_sec : vypadek_sec;
    item->minimum_sec = (item->minimum_sec < vypadek_sec) ? item->minimum_sec : vypadek_sec;
}


void TimeStoreStatistics(tStatTimeItem *item, unsigned long long casImpulzu_ns, int pulzKompletni, unsigned long long vypadek_ns, int vypadek_pulzy, int superpozice)
{
	double casImpulzu_sec = (double)casImpulzu_ns / 1000000000.0;

	if (item->timeFirstImpulse_sec == 0) item->timeFirstImpulse_sec = casImpulzu_sec;
    item->timeLastImpulse_sec = casImpulzu_sec;
    item->numberAllImpulses++;
    if (!pulzKompletni) item->numberNotCompletedImpulses++;
    if (superpozice) item->numberSuperposedImpulses++;

    if (vypadek_pulzy > 0)
    {
        if (vypadek_ns < 30000) TimeStoreLossStatistics(&item->shortLoss, vypadek_ns, vypadek_pulzy);            //less than 30 us
        else if (vypadek_ns < 1000000) TimeStoreLossStatistics(&item->mediumLoss, vypadek_ns, vypadek_pulzy);    //less than 1 ms
        else TimeStoreLossStatistics(&item->longLoss, vypadek_ns, vypadek_pulzy);                                //greater than 1 ms
    }
}

int TimePrintLossStatistics(char* s, tStatTimeLossItem *item, char* text)
{
    int charNum = 0;

    double mean = (double)item->sum_sec / (double)item->numLoss;
	double stdPow2 = ((double)item->sumPow2_sec/(double)item->numLoss) - mean*mean;
	double std = (stdPow2 > 0) ? sqrt(stdPow2) : 0;
	double min = item->minimum_sec;
	double max = item->maximum_sec;

    //eliminate to write int and nan
	if (item->numLoss == 0)
    {
        mean = std = min = max = 0;
    }

	charNum += sprintf(s + charNum,     "%8s | %1.0es   %1.0es   %1.0es   %1.0es  | %11llu  %11llu\n", text, min, mean, std, max, item->numLoss, item->numLossImpulses);

	return charNum;
}




int TimePrintStatistics(char* s, tStatTimeItem *statItem)
{
	int charNum = 0;

	double start = statItem->timeFirstImpulse_sec;
	double stop = statItem->timeLastImpulse_sec;
	double loss = statItem->shortLoss.sum_sec + statItem->mediumLoss.sum_sec + statItem->longLoss.sum_sec;
	double timeWithLoss = stop - start;
	double timeWithoutLoss = timeWithLoss - loss;
	double freqWithLoss = (double)statItem->numberAllImpulses / timeWithLoss;
	double freqWithoutLoss = (double)statItem->numberAllImpulses / timeWithoutLoss;

	charNum += sprintf(s + charNum, "%1.1fs -> %1.1fs (prvni pulz %1.1fs)\n\n", start, stop, timeOfFirstReceivedPulse_sec);

	charNum += sprintf(s + charNum, "CAS s vypadky %7.1fs    FREKVENCE s vypadky  %7.1fs-1\n", timeWithLoss, freqWithLoss);
    charNum += sprintf(s + charNum, "  bez vypadku %7.1fs            bez vypadku  %7.1fs-1\n", timeWithoutLoss, freqWithoutLoss);
	charNum += sprintf(s + charNum, "\n");

	unsigned long long notDiscImpulses = statItem->numberAllImpulses - statItem->numberNotCompletedImpulses - statItem->numberSuperposedImpulses;
    charNum += sprintf(s + charNum, "Nekompl.pulzy (vypadek) %10llu     Ulozene pulzy do CSV %10llu\n", statItem->numberNotCompletedImpulses, notDiscImpulses);
    charNum += sprintf(s + charNum, "Superponovane pulzy     %10llu     Celkem pulzu         %10llu\n", statItem->numberSuperposedImpulses, statItem->numberAllImpulses);
	charNum += sprintf(s + charNum, "\n");


    charNum += sprintf(s + charNum, "VYPADKY  | minimum    mean     std    maximum | poc.vypadku  ztrac.pulzu\n");
	charNum += sprintf(s + charNum, "------------------------------------------------------------------------\n");
	charNum += TimePrintLossStatistics(s + charNum, &statItem->shortLoss,  "do 30us");
    charNum += TimePrintLossStatistics(s + charNum, &statItem->mediumLoss, "30us-1ms");
    charNum += TimePrintLossStatistics(s + charNum, &statItem->longLoss,   "nad 1ms");




	return charNum;
}




void SetTimeOfFirstReceivedPulse(unsigned long long time)
{
	if (timeOfFirstReceivedPulse_sec == 0)
	{
		timeOfFirstReceivedPulse_sec = (double)time / 1000000000.0;
	}
}

///statistics only about saved impulses
void TimeStatsOfSavedImpulses(tStatTime *stats, unsigned long long casImpulzu_ns, int pulzKompletni, unsigned long long vypadek_ns, int vypadek_pulzy, int superpozice)
{
    TimeStoreStatistics(&stats->actual, casImpulzu_ns, pulzKompletni, vypadek_ns, vypadek_pulzy, superpozice);
    TimeStoreStatistics(&stats->total, casImpulzu_ns, pulzKompletni, vypadek_ns, vypadek_pulzy, superpozice);
}

void PrintS(ParamsStruct *params)
{
	printf("\n\n\n\n\n\n\n\n\n\n");

	//print command line parameters
	PrintValues(params, 0, stdout);

	printf("%s%s", statsTextActual, statsTextTotal);

	printf("\n\n");
	printf("--------------------------------------------------------------------------------\n");
	printf("UDP / HDD STATISTIKA\n\n");
	printf("Zpracovano impulsu    %11lld    |    Rychlost (s-1)  %7lld    |    %s     \r\n", pocitadlo_impulsu, pocitadlo_impulsu - pocitadlo_impulsu_prev, ((stav) ? "\\" : "/"));
	printf("--------------------------------------------------------------------------------\n");
	fflush(stdout);
	pocitadlo_impulsu_prev = pocitadlo_impulsu;
	stav = (stav) ? 0 : 1;
}


///Kazdou sekundu vypise statistiku
void PrintStatistics(ParamsStruct *params)
{
	if (time(NULL) != previousTime)
	{
		PrintS(params);
		previousTime = time(NULL);
	}
}


int ZastavZpracovani(ParamsStruct *params)
{
	int stop = 0;

	if (params->POCET_IMPULSU > 0 && params->POCET_IMPULSU < pocitadlo_impulsu)
	{
		stop = 1;
	}

	return stop;
}




void WriteActualStatsToString(unsigned long long beginOfInterval_ns, tStatDynamZero *DynamZeroStatCH1, tStatDynamZero *DynamZeroStatCH2, tBranchFusingStat *branchFusingStats, tStatEnergy *energyStats, tStatTime *timeStats)
{
	//clear string
	statsTextActual[0] = 0;
	char* statsTextActual_point = statsTextActual;

	statsTextActual_point += sprintf(statsTextActual_point, "\n\n");
	statsTextActual_point += sprintf(statsTextActual_point, "--------------------------------------------------------------------------------\n");
	statsTextActual_point += sprintf(statsTextActual_point, "AKTUALNI STATISTIKA    %1.3fs -> %1.3fs\n", (double)beginOfInterval_ns/1000000000.0, (double)timeOfNextStats_ns/1000000000.0);
	statsTextActual_point += sprintf(statsTextActual_point, "\n");

	//time statistic
	statsTextActual_point += TimePrintStatistics(statsTextActual_point, &timeStats->actual);
	statsTextActual_point += sprintf(statsTextActual_point, "\n");

	//dynam zero
	statsTextActual_point += DynamZeroPrintStatistics(statsTextActual_point, 1, DynamZeroStatCH1->histogramActual, "CH1");
	statsTextActual_point += DynamZeroPrintStatistics(statsTextActual_point, 0, DynamZeroStatCH2->histogramActual, "CH2");

    //branch fusing
	statsTextActual_point += sprintf(statsTextActual_point, "\n");
	statsTextActual_point += BranchFusingPrintStatistics(statsTextActual_point, 1, &branchFusingStats->actualRAW, "RAW data");
	statsTextActual_point += BranchFusingPrintStatistics(statsTextActual_point, 0, &branchFusingStats->actualIIR, "after IIR");

	//energy of impulse
	statsTextActual_point += sprintf(statsTextActual_point, "\n");
	statsTextActual_point += EnergyPrintStatistics(statsTextActual_point, 1, &energyStats->actual);

	statsTextActual_point += sprintf(statsTextActual_point, "--------------------------------------------------------------------------------\n");
}




void WriteTotalStatsToString(tStatDynamZero *DynamZeroStatCH1, tStatDynamZero *DynamZeroStatCH2, tBranchFusingStat *branchFusingStats, tStatEnergy *energyStats, tStatTime *timeStats)
{
	statsTextTotal[0] = 0;
	char* statsTextTotal_point = statsTextTotal;

	statsTextTotal_point += sprintf(statsTextTotal_point, "\n\n");
	statsTextTotal_point += sprintf(statsTextTotal_point, "--------------------------------------------------------------------------------\n");
	statsTextTotal_point += sprintf(statsTextTotal_point, "CELKOVA STATISTIKA ", timeOfFirstReceivedPulse_sec);

	//time statistic
	statsTextTotal_point += TimePrintStatistics(statsTextTotal_point, &timeStats->total);
	statsTextTotal_point += sprintf(statsTextTotal_point, "\n");

	//dynamic zero
	statsTextTotal_point += DynamZeroPrintStatistics(statsTextTotal_point, 1, DynamZeroStatCH1->histogramTotal, "CH1");
	statsTextTotal_point += DynamZeroPrintStatistics(statsTextTotal_point, 0, DynamZeroStatCH2->histogramTotal, "CH2");
	statsTextTotal_point += sprintf(statsTextTotal_point, "\n");

	//branch fusing
	statsTextTotal_point += BranchFusingPrintStatistics(statsTextTotal_point, 1, &branchFusingStats->totalRAW, "RAW data");
	statsTextTotal_point += BranchFusingPrintStatistics(statsTextTotal_point, 0, &branchFusingStats->totalIIR, "after IIR");
	statsTextTotal_point += sprintf(statsTextTotal_point, "\n");

	//energy of impulse
	statsTextTotal_point += EnergyPrintStatistics(statsTextTotal_point, 1, &energyStats->total);
	statsTextTotal_point += sprintf(statsTextTotal_point, "\n");

	//computing multiplicative constant
	statsTextTotal_point += BranchFusingPrintStatisticsMultConst(statsTextTotal_point, branchFusingStats);

	statsTextTotal_point += sprintf(statsTextTotal_point, "--------------------------------------------------------------------------------\n");
}


void PrintTotalStats(ParamsStruct *params, tStatDynamZero *DynamZeroStatCH1, tStatDynamZero *DynamZeroStatCH2, tBranchFusingStat *branchFusingStats, tStatEnergy *energyStats, tStatTime *timeStats)
{
	WriteTotalStatsToString(DynamZeroStatCH1, DynamZeroStatCH2, branchFusingStats, energyStats, timeStats);
	PrintS(params);

	//write statistics to file
    fprintf(statisticsFile, "%s%s\n\n\n\n\n\n", statsTextActual, statsTextTotal);
}



///Zapise ve vhodne dobe statistiku do stringu
///Vola se pred zpracovavanim kazdeho spravneho pulzu
void WriteAllStatsToString(unsigned long long casImpulzu_ns, ParamsStruct *params, tStatDynamZero *DynamZeroStatCH1, tStatDynamZero *DynamZeroStatCH2, tBranchFusingStat *branchFusingStats, tStatEnergy *energyStats, tStatTime *timeStats)
{
	pocitadlo_impulsu++;

	if (casImpulzu_ns > timeOfNextStats_ns)
	{
		unsigned long long statsInterval_ns = (unsigned long long)params->STATS_INTERVAL_MS * 1000000ll;
		unsigned long long beginOfInterval_ns = timeOfNextStats_ns - statsInterval_ns;

        //compute and write statis to string
		WriteActualStatsToString(beginOfInterval_ns, DynamZeroStatCH1, DynamZeroStatCH2, branchFusingStats, energyStats, timeStats);
		WriteTotalStatsToString(DynamZeroStatCH1, DynamZeroStatCH2, branchFusingStats, energyStats, timeStats);

		//write statistics to file
        fprintf(statisticsFile, "%s%s\n\n\n\n\n\n", statsTextActual, statsTextTotal);

		//clear statistics
		DynamZeroClearStatistics(DynamZeroStatCH1, 1);
		DynamZeroClearStatistics(DynamZeroStatCH2, 1);
		BranchFusingClearStatistics(branchFusingStats, 1, 0);
		EnergyClearStatistics(energyStats, 1);
		TimeClearStatistics(timeStats, 1);

		//time of next statistics
		timeOfNextStats_ns = (casImpulzu_ns / statsInterval_ns)*statsInterval_ns + statsInterval_ns;
	}
}
